/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIPrefMigrationProgress.idl
 */

#ifndef __gen_nsIPrefMigrationProgress_h__
#define __gen_nsIPrefMigrationProgress_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIPrefMigrationProgress */
#define NS_IPREFMIGRATIONPROGRESS_IID_STR "7da18222-6a6b-11d3-8316-004005263078"

#define NS_IPREFMIGRATIONPROGRESS_IID \
  {0x7da18222, 0x6a6b, 0x11d3, \
    { 0x83, 0x16, 0x00, 0x40, 0x05, 0x26, 0x30, 0x78 }}

class NS_NO_VTABLE nsIPrefMigrationProgress : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IPREFMIGRATIONPROGRESS_IID)

  /* void CreateProfileProgressDialog (); */
  NS_IMETHOD CreateProfileProgressDialog(void) = 0;

  /* void MigrationStarted ([const] in string UIPackageName); */
  NS_IMETHOD MigrationStarted(const char *UIPackageName) = 0;

  /* void IncrementProgressBar (); */
  NS_IMETHOD IncrementProgressBar(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPREFMIGRATIONPROGRESS \
  NS_IMETHOD CreateProfileProgressDialog(void); \
  NS_IMETHOD MigrationStarted(const char *UIPackageName); \
  NS_IMETHOD IncrementProgressBar(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPREFMIGRATIONPROGRESS(_to) \
  NS_IMETHOD CreateProfileProgressDialog(void) { return _to CreateProfileProgressDialog(); } \
  NS_IMETHOD MigrationStarted(const char *UIPackageName) { return _to MigrationStarted(UIPackageName); } \
  NS_IMETHOD IncrementProgressBar(void) { return _to IncrementProgressBar(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPREFMIGRATIONPROGRESS(_to) \
  NS_IMETHOD CreateProfileProgressDialog(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateProfileProgressDialog(); } \
  NS_IMETHOD MigrationStarted(const char *UIPackageName) { return !_to ? NS_ERROR_NULL_POINTER : _to->MigrationStarted(UIPackageName); } \
  NS_IMETHOD IncrementProgressBar(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->IncrementProgressBar(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPrefMigrationProgress : public nsIPrefMigrationProgress
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPREFMIGRATIONPROGRESS

  nsPrefMigrationProgress();

private:
  ~nsPrefMigrationProgress();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPrefMigrationProgress, nsIPrefMigrationProgress)

nsPrefMigrationProgress::nsPrefMigrationProgress()
{
  /* member initializers and constructor code */
}

nsPrefMigrationProgress::~nsPrefMigrationProgress()
{
  /* destructor code */
}

/* void CreateProfileProgressDialog (); */
NS_IMETHODIMP nsPrefMigrationProgress::CreateProfileProgressDialog()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void MigrationStarted ([const] in string UIPackageName); */
NS_IMETHODIMP nsPrefMigrationProgress::MigrationStarted(const char *UIPackageName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void IncrementProgressBar (); */
NS_IMETHODIMP nsPrefMigrationProgress::IncrementProgressBar()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPrefMigrationProgress_h__ */
