/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIDBFolderInfo.idl
 */

#ifndef __gen_nsIDBFolderInfo_h__
#define __gen_nsIDBFolderInfo_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDBFolderInfo */
#define NS_IDBFOLDERINFO_IID_STR "5cb11c00-cb8b-11d2-8d67-00805f8a6617"

#define NS_IDBFOLDERINFO_IID \
  {0x5cb11c00, 0xcb8b, 0x11d2, \
    { 0x8d, 0x67, 0x00, 0x80, 0x5f, 0x8a, 0x66, 0x17 }}

class NS_NO_VTABLE nsIDBFolderInfo : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDBFOLDERINFO_IID)

  /* attribute long Flags; */
  NS_IMETHOD GetFlags(PRInt32 *aFlags) = 0;
  NS_IMETHOD SetFlags(PRInt32 aFlags) = 0;

  /* long OrFlags (in long flags); */
  NS_IMETHOD OrFlags(PRInt32 flags, PRInt32 *_retval) = 0;

  /* long AndFlags (in long flags); */
  NS_IMETHOD AndFlags(PRInt32 flags, PRInt32 *_retval) = 0;

  /* void SetHighWater (in nsMsgKey highwater, in boolean force); */
  NS_IMETHOD SetHighWater(nsMsgKey highwater, PRBool force) = 0;

  /* attribute nsMsgKey HighWater; */
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater) = 0;
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater) = 0;

  /* attribute nsMsgKey ExpiredMark; */
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark) = 0;
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark) = 0;

  /* attribute unsigned long FolderSize; */
  NS_IMETHOD GetFolderSize(PRUint32 *aFolderSize) = 0;
  NS_IMETHOD SetFolderSize(PRUint32 aFolderSize) = 0;

  /* attribute unsigned long FolderDate; */
  NS_IMETHOD GetFolderDate(PRUint32 *aFolderDate) = 0;
  NS_IMETHOD SetFolderDate(PRUint32 aFolderDate) = 0;

  /* void ChangeNumUnreadMessages (in long delta); */
  NS_IMETHOD ChangeNumUnreadMessages(PRInt32 delta) = 0;

  /* void ChangeNumMessages (in long delta); */
  NS_IMETHOD ChangeNumMessages(PRInt32 delta) = 0;

  /* attribute long NumUnreadMessages; */
  NS_IMETHOD GetNumUnreadMessages(PRInt32 *aNumUnreadMessages) = 0;
  NS_IMETHOD SetNumUnreadMessages(PRInt32 aNumUnreadMessages) = 0;

  /* attribute long NumMessages; */
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages) = 0;
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages) = 0;

  /* attribute long expungedBytes; */
  NS_IMETHOD GetExpungedBytes(PRInt32 *aExpungedBytes) = 0;
  NS_IMETHOD SetExpungedBytes(PRInt32 aExpungedBytes) = 0;

  /* attribute long ImapUidValidity; */
  NS_IMETHOD GetImapUidValidity(PRInt32 *aImapUidValidity) = 0;
  NS_IMETHOD SetImapUidValidity(PRInt32 aImapUidValidity) = 0;

  /* attribute unsigned long Version; */
  NS_IMETHOD GetVersion(PRUint32 *aVersion) = 0;
  NS_IMETHOD SetVersion(PRUint32 aVersion) = 0;

  /* attribute long ImapTotalPendingMessages; */
  NS_IMETHOD GetImapTotalPendingMessages(PRInt32 *aImapTotalPendingMessages) = 0;
  NS_IMETHOD SetImapTotalPendingMessages(PRInt32 aImapTotalPendingMessages) = 0;

  /* attribute long ImapUnreadPendingMessages; */
  NS_IMETHOD GetImapUnreadPendingMessages(PRInt32 *aImapUnreadPendingMessages) = 0;
  NS_IMETHOD SetImapUnreadPendingMessages(PRInt32 aImapUnreadPendingMessages) = 0;

  /* attribute wchar IMAPHierarchySeparator; */
  NS_IMETHOD GetIMAPHierarchySeparator(PRUnichar *aIMAPHierarchySeparator) = 0;
  NS_IMETHOD SetIMAPHierarchySeparator(PRUnichar aIMAPHierarchySeparator) = 0;

  /* attribute nsMsgViewTypeValue viewType; */
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType) = 0;
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType) = 0;

  /* attribute nsMsgViewFlagsTypeValue viewFlags; */
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags) = 0;
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags) = 0;

  /* attribute nsMsgViewSortTypeValue sortType; */
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType) = 0;
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType) = 0;

  /* attribute nsMsgViewSortOrderValue sortOrder; */
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder) = 0;
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder) = 0;

  /* void ChangeExpungedBytes (in long delta); */
  NS_IMETHOD ChangeExpungedBytes(PRInt32 delta) = 0;

  /* string getCharPtrProperty (in string propertyName); */
  NS_IMETHOD GetCharPtrProperty(const char *propertyName, char **_retval) = 0;

  /* void setCharPtrProperty (in string aPropertyName, in string aPropertyValue); */
  NS_IMETHOD SetCharPtrProperty(const char *aPropertyName, const char *aPropertyValue) = 0;

  /* void setUint32Property (in string propertyName, in unsigned long propertyValue); */
  NS_IMETHOD SetUint32Property(const char *propertyName, PRUint32 propertyValue) = 0;

  /* unsigned long getUint32Property (in string propertyName, in unsigned long defaultValue); */
  NS_IMETHOD GetUint32Property(const char *propertyName, PRUint32 defaultValue, PRUint32 *_retval) = 0;

  /* boolean getBooleanProperty (in string propertyName, in boolean defaultValue); */
  NS_IMETHOD GetBooleanProperty(const char *propertyName, PRBool defaultValue, PRBool *_retval) = 0;

  /* void setBooleanProperty (in string propertyName, in boolean aPropertyValue); */
  NS_IMETHOD SetBooleanProperty(const char *propertyName, PRBool aPropertyValue) = 0;

  /* nsIDBFolderInfo GetTransferInfo (); */
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo **_retval) = 0;

  /* void initFromTransferInfo (in nsIDBFolderInfo transferInfo); */
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo) = 0;

  /* void getCharacterSet (out ACString charSet, out boolean overriden); */
  NS_IMETHOD GetCharacterSet(nsACString & charSet, PRBool *overriden) = 0;

  /* void setCharacterSet (in string charSet); */
  NS_IMETHOD SetCharacterSet(const char *charSet) = 0;

  /* attribute boolean characterSetOverride; */
  NS_IMETHOD GetCharacterSetOverride(PRBool *aCharacterSetOverride) = 0;
  NS_IMETHOD SetCharacterSetOverride(PRBool aCharacterSetOverride) = 0;

  /* string getCharPtrCharacterSet (); */
  NS_IMETHOD GetCharPtrCharacterSet(char **_retval) = 0;

  /* attribute AString locale; */
  NS_IMETHOD GetLocale(nsAString & aLocale) = 0;
  NS_IMETHOD SetLocale(const nsAString & aLocale) = 0;

  /* attribute AString mailboxName; */
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName) = 0;
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName) = 0;

  /* AString getProperty (in string propertyName); */
  NS_IMETHOD GetProperty(const char *propertyName, nsAString & _retval) = 0;

  /* void setProperty (in string propertyName, in AString propertyStr); */
  NS_IMETHOD SetProperty(const char *propertyName, const nsAString & propertyStr) = 0;

  /* attribute string knownArtsSet; */
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet) = 0;
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet) = 0;

  /* attribute string folderName; */
  NS_IMETHOD GetFolderName(char * *aFolderName) = 0;
  NS_IMETHOD SetFolderName(const char * aFolderName) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDBFOLDERINFO \
  NS_IMETHOD GetFlags(PRInt32 *aFlags); \
  NS_IMETHOD SetFlags(PRInt32 aFlags); \
  NS_IMETHOD OrFlags(PRInt32 flags, PRInt32 *_retval); \
  NS_IMETHOD AndFlags(PRInt32 flags, PRInt32 *_retval); \
  NS_IMETHOD SetHighWater(nsMsgKey highwater, PRBool force); \
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater); \
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater); \
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark); \
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark); \
  NS_IMETHOD GetFolderSize(PRUint32 *aFolderSize); \
  NS_IMETHOD SetFolderSize(PRUint32 aFolderSize); \
  NS_IMETHOD GetFolderDate(PRUint32 *aFolderDate); \
  NS_IMETHOD SetFolderDate(PRUint32 aFolderDate); \
  NS_IMETHOD ChangeNumUnreadMessages(PRInt32 delta); \
  NS_IMETHOD ChangeNumMessages(PRInt32 delta); \
  NS_IMETHOD GetNumUnreadMessages(PRInt32 *aNumUnreadMessages); \
  NS_IMETHOD SetNumUnreadMessages(PRInt32 aNumUnreadMessages); \
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages); \
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages); \
  NS_IMETHOD GetExpungedBytes(PRInt32 *aExpungedBytes); \
  NS_IMETHOD SetExpungedBytes(PRInt32 aExpungedBytes); \
  NS_IMETHOD GetImapUidValidity(PRInt32 *aImapUidValidity); \
  NS_IMETHOD SetImapUidValidity(PRInt32 aImapUidValidity); \
  NS_IMETHOD GetVersion(PRUint32 *aVersion); \
  NS_IMETHOD SetVersion(PRUint32 aVersion); \
  NS_IMETHOD GetImapTotalPendingMessages(PRInt32 *aImapTotalPendingMessages); \
  NS_IMETHOD SetImapTotalPendingMessages(PRInt32 aImapTotalPendingMessages); \
  NS_IMETHOD GetImapUnreadPendingMessages(PRInt32 *aImapUnreadPendingMessages); \
  NS_IMETHOD SetImapUnreadPendingMessages(PRInt32 aImapUnreadPendingMessages); \
  NS_IMETHOD GetIMAPHierarchySeparator(PRUnichar *aIMAPHierarchySeparator); \
  NS_IMETHOD SetIMAPHierarchySeparator(PRUnichar aIMAPHierarchySeparator); \
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType); \
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType); \
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags); \
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags); \
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType); \
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType); \
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder); \
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder); \
  NS_IMETHOD ChangeExpungedBytes(PRInt32 delta); \
  NS_IMETHOD GetCharPtrProperty(const char *propertyName, char **_retval); \
  NS_IMETHOD SetCharPtrProperty(const char *aPropertyName, const char *aPropertyValue); \
  NS_IMETHOD SetUint32Property(const char *propertyName, PRUint32 propertyValue); \
  NS_IMETHOD GetUint32Property(const char *propertyName, PRUint32 defaultValue, PRUint32 *_retval); \
  NS_IMETHOD GetBooleanProperty(const char *propertyName, PRBool defaultValue, PRBool *_retval); \
  NS_IMETHOD SetBooleanProperty(const char *propertyName, PRBool aPropertyValue); \
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo **_retval); \
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo); \
  NS_IMETHOD GetCharacterSet(nsACString & charSet, PRBool *overriden); \
  NS_IMETHOD SetCharacterSet(const char *charSet); \
  NS_IMETHOD GetCharacterSetOverride(PRBool *aCharacterSetOverride); \
  NS_IMETHOD SetCharacterSetOverride(PRBool aCharacterSetOverride); \
  NS_IMETHOD GetCharPtrCharacterSet(char **_retval); \
  NS_IMETHOD GetLocale(nsAString & aLocale); \
  NS_IMETHOD SetLocale(const nsAString & aLocale); \
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName); \
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName); \
  NS_IMETHOD GetProperty(const char *propertyName, nsAString & _retval); \
  NS_IMETHOD SetProperty(const char *propertyName, const nsAString & propertyStr); \
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet); \
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet); \
  NS_IMETHOD GetFolderName(char * *aFolderName); \
  NS_IMETHOD SetFolderName(const char * aFolderName); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDBFOLDERINFO(_to) \
  NS_IMETHOD GetFlags(PRInt32 *aFlags) { return _to GetFlags(aFlags); } \
  NS_IMETHOD SetFlags(PRInt32 aFlags) { return _to SetFlags(aFlags); } \
  NS_IMETHOD OrFlags(PRInt32 flags, PRInt32 *_retval) { return _to OrFlags(flags, _retval); } \
  NS_IMETHOD AndFlags(PRInt32 flags, PRInt32 *_retval) { return _to AndFlags(flags, _retval); } \
  NS_IMETHOD SetHighWater(nsMsgKey highwater, PRBool force) { return _to SetHighWater(highwater, force); } \
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater) { return _to GetHighWater(aHighWater); } \
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater) { return _to SetHighWater(aHighWater); } \
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark) { return _to GetExpiredMark(aExpiredMark); } \
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark) { return _to SetExpiredMark(aExpiredMark); } \
  NS_IMETHOD GetFolderSize(PRUint32 *aFolderSize) { return _to GetFolderSize(aFolderSize); } \
  NS_IMETHOD SetFolderSize(PRUint32 aFolderSize) { return _to SetFolderSize(aFolderSize); } \
  NS_IMETHOD GetFolderDate(PRUint32 *aFolderDate) { return _to GetFolderDate(aFolderDate); } \
  NS_IMETHOD SetFolderDate(PRUint32 aFolderDate) { return _to SetFolderDate(aFolderDate); } \
  NS_IMETHOD ChangeNumUnreadMessages(PRInt32 delta) { return _to ChangeNumUnreadMessages(delta); } \
  NS_IMETHOD ChangeNumMessages(PRInt32 delta) { return _to ChangeNumMessages(delta); } \
  NS_IMETHOD GetNumUnreadMessages(PRInt32 *aNumUnreadMessages) { return _to GetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD SetNumUnreadMessages(PRInt32 aNumUnreadMessages) { return _to SetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages) { return _to GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages) { return _to SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetExpungedBytes(PRInt32 *aExpungedBytes) { return _to GetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD SetExpungedBytes(PRInt32 aExpungedBytes) { return _to SetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD GetImapUidValidity(PRInt32 *aImapUidValidity) { return _to GetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD SetImapUidValidity(PRInt32 aImapUidValidity) { return _to SetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD GetVersion(PRUint32 *aVersion) { return _to GetVersion(aVersion); } \
  NS_IMETHOD SetVersion(PRUint32 aVersion) { return _to SetVersion(aVersion); } \
  NS_IMETHOD GetImapTotalPendingMessages(PRInt32 *aImapTotalPendingMessages) { return _to GetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD SetImapTotalPendingMessages(PRInt32 aImapTotalPendingMessages) { return _to SetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD GetImapUnreadPendingMessages(PRInt32 *aImapUnreadPendingMessages) { return _to GetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD SetImapUnreadPendingMessages(PRInt32 aImapUnreadPendingMessages) { return _to SetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD GetIMAPHierarchySeparator(PRUnichar *aIMAPHierarchySeparator) { return _to GetIMAPHierarchySeparator(aIMAPHierarchySeparator); } \
  NS_IMETHOD SetIMAPHierarchySeparator(PRUnichar aIMAPHierarchySeparator) { return _to SetIMAPHierarchySeparator(aIMAPHierarchySeparator); } \
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType) { return _to GetViewType(aViewType); } \
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType) { return _to SetViewType(aViewType); } \
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags) { return _to GetViewFlags(aViewFlags); } \
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags) { return _to SetViewFlags(aViewFlags); } \
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType) { return _to GetSortType(aSortType); } \
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType) { return _to SetSortType(aSortType); } \
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder) { return _to GetSortOrder(aSortOrder); } \
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder) { return _to SetSortOrder(aSortOrder); } \
  NS_IMETHOD ChangeExpungedBytes(PRInt32 delta) { return _to ChangeExpungedBytes(delta); } \
  NS_IMETHOD GetCharPtrProperty(const char *propertyName, char **_retval) { return _to GetCharPtrProperty(propertyName, _retval); } \
  NS_IMETHOD SetCharPtrProperty(const char *aPropertyName, const char *aPropertyValue) { return _to SetCharPtrProperty(aPropertyName, aPropertyValue); } \
  NS_IMETHOD SetUint32Property(const char *propertyName, PRUint32 propertyValue) { return _to SetUint32Property(propertyName, propertyValue); } \
  NS_IMETHOD GetUint32Property(const char *propertyName, PRUint32 defaultValue, PRUint32 *_retval) { return _to GetUint32Property(propertyName, defaultValue, _retval); } \
  NS_IMETHOD GetBooleanProperty(const char *propertyName, PRBool defaultValue, PRBool *_retval) { return _to GetBooleanProperty(propertyName, defaultValue, _retval); } \
  NS_IMETHOD SetBooleanProperty(const char *propertyName, PRBool aPropertyValue) { return _to SetBooleanProperty(propertyName, aPropertyValue); } \
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo **_retval) { return _to GetTransferInfo(_retval); } \
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo) { return _to InitFromTransferInfo(transferInfo); } \
  NS_IMETHOD GetCharacterSet(nsACString & charSet, PRBool *overriden) { return _to GetCharacterSet(charSet, overriden); } \
  NS_IMETHOD SetCharacterSet(const char *charSet) { return _to SetCharacterSet(charSet); } \
  NS_IMETHOD GetCharacterSetOverride(PRBool *aCharacterSetOverride) { return _to GetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD SetCharacterSetOverride(PRBool aCharacterSetOverride) { return _to SetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD GetCharPtrCharacterSet(char **_retval) { return _to GetCharPtrCharacterSet(_retval); } \
  NS_IMETHOD GetLocale(nsAString & aLocale) { return _to GetLocale(aLocale); } \
  NS_IMETHOD SetLocale(const nsAString & aLocale) { return _to SetLocale(aLocale); } \
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName) { return _to GetMailboxName(aMailboxName); } \
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName) { return _to SetMailboxName(aMailboxName); } \
  NS_IMETHOD GetProperty(const char *propertyName, nsAString & _retval) { return _to GetProperty(propertyName, _retval); } \
  NS_IMETHOD SetProperty(const char *propertyName, const nsAString & propertyStr) { return _to SetProperty(propertyName, propertyStr); } \
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet) { return _to GetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet) { return _to SetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD GetFolderName(char * *aFolderName) { return _to GetFolderName(aFolderName); } \
  NS_IMETHOD SetFolderName(const char * aFolderName) { return _to SetFolderName(aFolderName); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDBFOLDERINFO(_to) \
  NS_IMETHOD GetFlags(PRInt32 *aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFlags(aFlags); } \
  NS_IMETHOD SetFlags(PRInt32 aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFlags(aFlags); } \
  NS_IMETHOD OrFlags(PRInt32 flags, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->OrFlags(flags, _retval); } \
  NS_IMETHOD AndFlags(PRInt32 flags, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AndFlags(flags, _retval); } \
  NS_IMETHOD SetHighWater(nsMsgKey highwater, PRBool force) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHighWater(highwater, force); } \
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHighWater(aHighWater); } \
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHighWater(aHighWater); } \
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExpiredMark(aExpiredMark); } \
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetExpiredMark(aExpiredMark); } \
  NS_IMETHOD GetFolderSize(PRUint32 *aFolderSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderSize(aFolderSize); } \
  NS_IMETHOD SetFolderSize(PRUint32 aFolderSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderSize(aFolderSize); } \
  NS_IMETHOD GetFolderDate(PRUint32 *aFolderDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderDate(aFolderDate); } \
  NS_IMETHOD SetFolderDate(PRUint32 aFolderDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderDate(aFolderDate); } \
  NS_IMETHOD ChangeNumUnreadMessages(PRInt32 delta) { return !_to ? NS_ERROR_NULL_POINTER : _to->ChangeNumUnreadMessages(delta); } \
  NS_IMETHOD ChangeNumMessages(PRInt32 delta) { return !_to ? NS_ERROR_NULL_POINTER : _to->ChangeNumMessages(delta); } \
  NS_IMETHOD GetNumUnreadMessages(PRInt32 *aNumUnreadMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD SetNumUnreadMessages(PRInt32 aNumUnreadMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetExpungedBytes(PRInt32 *aExpungedBytes) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD SetExpungedBytes(PRInt32 aExpungedBytes) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD GetImapUidValidity(PRInt32 *aImapUidValidity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD SetImapUidValidity(PRInt32 aImapUidValidity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD GetVersion(PRUint32 *aVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetVersion(aVersion); } \
  NS_IMETHOD SetVersion(PRUint32 aVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetVersion(aVersion); } \
  NS_IMETHOD GetImapTotalPendingMessages(PRInt32 *aImapTotalPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD SetImapTotalPendingMessages(PRInt32 aImapTotalPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD GetImapUnreadPendingMessages(PRInt32 *aImapUnreadPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD SetImapUnreadPendingMessages(PRInt32 aImapUnreadPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD GetIMAPHierarchySeparator(PRUnichar *aIMAPHierarchySeparator) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIMAPHierarchySeparator(aIMAPHierarchySeparator); } \
  NS_IMETHOD SetIMAPHierarchySeparator(PRUnichar aIMAPHierarchySeparator) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIMAPHierarchySeparator(aIMAPHierarchySeparator); } \
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetViewType(aViewType); } \
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetViewType(aViewType); } \
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetViewFlags(aViewFlags); } \
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetViewFlags(aViewFlags); } \
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSortType(aSortType); } \
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSortType(aSortType); } \
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSortOrder(aSortOrder); } \
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSortOrder(aSortOrder); } \
  NS_IMETHOD ChangeExpungedBytes(PRInt32 delta) { return !_to ? NS_ERROR_NULL_POINTER : _to->ChangeExpungedBytes(delta); } \
  NS_IMETHOD GetCharPtrProperty(const char *propertyName, char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharPtrProperty(propertyName, _retval); } \
  NS_IMETHOD SetCharPtrProperty(const char *aPropertyName, const char *aPropertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharPtrProperty(aPropertyName, aPropertyValue); } \
  NS_IMETHOD SetUint32Property(const char *propertyName, PRUint32 propertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUint32Property(propertyName, propertyValue); } \
  NS_IMETHOD GetUint32Property(const char *propertyName, PRUint32 defaultValue, PRUint32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUint32Property(propertyName, defaultValue, _retval); } \
  NS_IMETHOD GetBooleanProperty(const char *propertyName, PRBool defaultValue, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBooleanProperty(propertyName, defaultValue, _retval); } \
  NS_IMETHOD SetBooleanProperty(const char *propertyName, PRBool aPropertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBooleanProperty(propertyName, aPropertyValue); } \
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTransferInfo(_retval); } \
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitFromTransferInfo(transferInfo); } \
  NS_IMETHOD GetCharacterSet(nsACString & charSet, PRBool *overriden) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharacterSet(charSet, overriden); } \
  NS_IMETHOD SetCharacterSet(const char *charSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharacterSet(charSet); } \
  NS_IMETHOD GetCharacterSetOverride(PRBool *aCharacterSetOverride) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD SetCharacterSetOverride(PRBool aCharacterSetOverride) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD GetCharPtrCharacterSet(char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharPtrCharacterSet(_retval); } \
  NS_IMETHOD GetLocale(nsAString & aLocale) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLocale(aLocale); } \
  NS_IMETHOD SetLocale(const nsAString & aLocale) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLocale(aLocale); } \
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailboxName(aMailboxName); } \
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMailboxName(aMailboxName); } \
  NS_IMETHOD GetProperty(const char *propertyName, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetProperty(propertyName, _retval); } \
  NS_IMETHOD SetProperty(const char *propertyName, const nsAString & propertyStr) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetProperty(propertyName, propertyStr); } \
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD GetFolderName(char * *aFolderName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderName(aFolderName); } \
  NS_IMETHOD SetFolderName(const char * aFolderName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderName(aFolderName); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDBFolderInfo : public nsIDBFolderInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDBFOLDERINFO

  nsDBFolderInfo();

private:
  ~nsDBFolderInfo();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDBFolderInfo, nsIDBFolderInfo)

nsDBFolderInfo::nsDBFolderInfo()
{
  /* member initializers and constructor code */
}

nsDBFolderInfo::~nsDBFolderInfo()
{
  /* destructor code */
}

/* attribute long Flags; */
NS_IMETHODIMP nsDBFolderInfo::GetFlags(PRInt32 *aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFlags(PRInt32 aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long OrFlags (in long flags); */
NS_IMETHODIMP nsDBFolderInfo::OrFlags(PRInt32 flags, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long AndFlags (in long flags); */
NS_IMETHODIMP nsDBFolderInfo::AndFlags(PRInt32 flags, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetHighWater (in nsMsgKey highwater, in boolean force); */
NS_IMETHODIMP nsDBFolderInfo::SetHighWater(nsMsgKey highwater, PRBool force)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgKey HighWater; */
NS_IMETHODIMP nsDBFolderInfo::GetHighWater(nsMsgKey *aHighWater)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetHighWater(nsMsgKey aHighWater)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgKey ExpiredMark; */
NS_IMETHODIMP nsDBFolderInfo::GetExpiredMark(nsMsgKey *aExpiredMark)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetExpiredMark(nsMsgKey aExpiredMark)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long FolderSize; */
NS_IMETHODIMP nsDBFolderInfo::GetFolderSize(PRUint32 *aFolderSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFolderSize(PRUint32 aFolderSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long FolderDate; */
NS_IMETHODIMP nsDBFolderInfo::GetFolderDate(PRUint32 *aFolderDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFolderDate(PRUint32 aFolderDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ChangeNumUnreadMessages (in long delta); */
NS_IMETHODIMP nsDBFolderInfo::ChangeNumUnreadMessages(PRInt32 delta)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ChangeNumMessages (in long delta); */
NS_IMETHODIMP nsDBFolderInfo::ChangeNumMessages(PRInt32 delta)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long NumUnreadMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetNumUnreadMessages(PRInt32 *aNumUnreadMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetNumUnreadMessages(PRInt32 aNumUnreadMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long NumMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetNumMessages(PRInt32 *aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetNumMessages(PRInt32 aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long expungedBytes; */
NS_IMETHODIMP nsDBFolderInfo::GetExpungedBytes(PRInt32 *aExpungedBytes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetExpungedBytes(PRInt32 aExpungedBytes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long ImapUidValidity; */
NS_IMETHODIMP nsDBFolderInfo::GetImapUidValidity(PRInt32 *aImapUidValidity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetImapUidValidity(PRInt32 aImapUidValidity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long Version; */
NS_IMETHODIMP nsDBFolderInfo::GetVersion(PRUint32 *aVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetVersion(PRUint32 aVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long ImapTotalPendingMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetImapTotalPendingMessages(PRInt32 *aImapTotalPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetImapTotalPendingMessages(PRInt32 aImapTotalPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long ImapUnreadPendingMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetImapUnreadPendingMessages(PRInt32 *aImapUnreadPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetImapUnreadPendingMessages(PRInt32 aImapUnreadPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute wchar IMAPHierarchySeparator; */
NS_IMETHODIMP nsDBFolderInfo::GetIMAPHierarchySeparator(PRUnichar *aIMAPHierarchySeparator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetIMAPHierarchySeparator(PRUnichar aIMAPHierarchySeparator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewTypeValue viewType; */
NS_IMETHODIMP nsDBFolderInfo::GetViewType(nsMsgViewTypeValue *aViewType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetViewType(nsMsgViewTypeValue aViewType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewFlagsTypeValue viewFlags; */
NS_IMETHODIMP nsDBFolderInfo::GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewSortTypeValue sortType; */
NS_IMETHODIMP nsDBFolderInfo::GetSortType(nsMsgViewSortTypeValue *aSortType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetSortType(nsMsgViewSortTypeValue aSortType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewSortOrderValue sortOrder; */
NS_IMETHODIMP nsDBFolderInfo::GetSortOrder(nsMsgViewSortOrderValue *aSortOrder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetSortOrder(nsMsgViewSortOrderValue aSortOrder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ChangeExpungedBytes (in long delta); */
NS_IMETHODIMP nsDBFolderInfo::ChangeExpungedBytes(PRInt32 delta)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string getCharPtrProperty (in string propertyName); */
NS_IMETHODIMP nsDBFolderInfo::GetCharPtrProperty(const char *propertyName, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setCharPtrProperty (in string aPropertyName, in string aPropertyValue); */
NS_IMETHODIMP nsDBFolderInfo::SetCharPtrProperty(const char *aPropertyName, const char *aPropertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setUint32Property (in string propertyName, in unsigned long propertyValue); */
NS_IMETHODIMP nsDBFolderInfo::SetUint32Property(const char *propertyName, PRUint32 propertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long getUint32Property (in string propertyName, in unsigned long defaultValue); */
NS_IMETHODIMP nsDBFolderInfo::GetUint32Property(const char *propertyName, PRUint32 defaultValue, PRUint32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getBooleanProperty (in string propertyName, in boolean defaultValue); */
NS_IMETHODIMP nsDBFolderInfo::GetBooleanProperty(const char *propertyName, PRBool defaultValue, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setBooleanProperty (in string propertyName, in boolean aPropertyValue); */
NS_IMETHODIMP nsDBFolderInfo::SetBooleanProperty(const char *propertyName, PRBool aPropertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIDBFolderInfo GetTransferInfo (); */
NS_IMETHODIMP nsDBFolderInfo::GetTransferInfo(nsIDBFolderInfo **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void initFromTransferInfo (in nsIDBFolderInfo transferInfo); */
NS_IMETHODIMP nsDBFolderInfo::InitFromTransferInfo(nsIDBFolderInfo *transferInfo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getCharacterSet (out ACString charSet, out boolean overriden); */
NS_IMETHODIMP nsDBFolderInfo::GetCharacterSet(nsACString & charSet, PRBool *overriden)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setCharacterSet (in string charSet); */
NS_IMETHODIMP nsDBFolderInfo::SetCharacterSet(const char *charSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean characterSetOverride; */
NS_IMETHODIMP nsDBFolderInfo::GetCharacterSetOverride(PRBool *aCharacterSetOverride)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetCharacterSetOverride(PRBool aCharacterSetOverride)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string getCharPtrCharacterSet (); */
NS_IMETHODIMP nsDBFolderInfo::GetCharPtrCharacterSet(char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString locale; */
NS_IMETHODIMP nsDBFolderInfo::GetLocale(nsAString & aLocale)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetLocale(const nsAString & aLocale)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString mailboxName; */
NS_IMETHODIMP nsDBFolderInfo::GetMailboxName(nsAString & aMailboxName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetMailboxName(const nsAString & aMailboxName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getProperty (in string propertyName); */
NS_IMETHODIMP nsDBFolderInfo::GetProperty(const char *propertyName, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setProperty (in string propertyName, in AString propertyStr); */
NS_IMETHODIMP nsDBFolderInfo::SetProperty(const char *propertyName, const nsAString & propertyStr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string knownArtsSet; */
NS_IMETHODIMP nsDBFolderInfo::GetKnownArtsSet(char * *aKnownArtsSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetKnownArtsSet(const char * aKnownArtsSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string folderName; */
NS_IMETHODIMP nsDBFolderInfo::GetFolderName(char * *aFolderName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFolderName(const char * aFolderName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDBFolderInfo_h__ */
