/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "MailNewsTypes2.idl"
// #include "nsIImapUrl.idl" // for imapMessageFlagsType

typedef unsigned short imapMessageFlagsType;

typedef long nsOfflineImapOperationType;

[scriptable, uuid(e576dace-db4f-4d23-aa6f-57165504848f)]

interface nsIMsgOfflineImapOperation : nsISupports
{
// type of stored imap operations
  const long kFlagsChanged      = 0x1;
  const long kMsgMoved          = 0x2;
  const long kMsgCopy           = 0x4;
  const long kMoveResult        = 0x8;
  const long kAppendDraft       = 0x10;
  const long kAddedHeader       = 0x20;
  const long kDeletedMsg        = 0x40;
  const long kMsgMarkedDeleted	= 0x80;
  const long kAppendTemplate    = 0x100;
  const long kDeleteAllMsgs     = 0x200;
  const long kAddKeywords       = 0x400;
  const long kRemoveKeywords    = 0x800;

  attribute nsOfflineImapOperationType operation;
  void clearOperation(in nsOfflineImapOperationType operation);
  attribute nsMsgKey messageKey;
  attribute imapMessageFlagsType flagOperation;
  attribute imapMessageFlagsType newFlags; // for kFlagsChanged
  attribute string destinationFolderURI; // for move or copy
  attribute string sourceFolderURI;
  void addKeywordToAdd(in string aKeyword);
  void addKeywordToRemove(in string aKeyword);
  readonly attribute string keywordsToAdd; 
  readonly attribute string keywordsToRemove;
  readonly attribute long numberOfCopies;
  void addMessageCopyOperation(in string destinationBox);
  string getCopyDestination(in long copyIndex);
  attribute unsigned long msgSize;
};

