/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIPop3Service.idl
 */

#ifndef __gen_nsIPop3Service_h__
#define __gen_nsIPop3Service_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlListener_h__
#include "nsIUrlListener.h"
#endif

#ifndef __gen_nsIPop3IncomingServer_h__
#include "nsIPop3IncomingServer.h"
#endif

#ifndef __gen_nsIMsgFolder_h__
#include "nsIMsgFolder.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIStreamListener; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIMsgFolder; /* forward declaration */


/* starting interface:    nsIPop3Service */
#define NS_IPOP3SERVICE_IID_STR "3bb459e0-d746-11d2-806a-006008128c4e"

#define NS_IPOP3SERVICE_IID \
  {0x3bb459e0, 0xd746, 0x11d2, \
    { 0x80, 0x6a, 0x00, 0x60, 0x08, 0x12, 0x8c, 0x4e }}

class NS_NO_VTABLE nsIPop3Service : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IPOP3SERVICE_IID)

  /* nsIURI GetNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aInbox, in nsIPop3IncomingServer popServer); */
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI **_retval) = 0;

  /* nsIURI CheckForNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder inbox, in nsIPop3IncomingServer popServer); */
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOP3SERVICE \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI **_retval); \
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOP3SERVICE(_to) \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI **_retval) { return _to GetNewMail(aMsgWindow, aUrlListener, aInbox, popServer, _retval); } \
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI **_retval) { return _to CheckForNewMail(aMsgWindow, aUrlListener, inbox, popServer, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOP3SERVICE(_to) \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewMail(aMsgWindow, aUrlListener, aInbox, popServer, _retval); } \
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CheckForNewMail(aMsgWindow, aUrlListener, inbox, popServer, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPop3Service : public nsIPop3Service
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOP3SERVICE

  nsPop3Service();

private:
  ~nsPop3Service();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPop3Service, nsIPop3Service)

nsPop3Service::nsPop3Service()
{
  /* member initializers and constructor code */
}

nsPop3Service::~nsPop3Service()
{
  /* destructor code */
}

/* nsIURI GetNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aInbox, in nsIPop3IncomingServer popServer); */
NS_IMETHODIMP nsPop3Service::GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI CheckForNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder inbox, in nsIPop3IncomingServer popServer); */
NS_IMETHODIMP nsPop3Service::CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPop3Service_h__ */
