/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIPolicyTarget.idl
 */

#ifndef __gen_nsIPolicyTarget_h__
#define __gen_nsIPolicyTarget_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIPolicyListener; /* forward declaration */


/* starting interface:    nsIPolicyTarget */
#define NS_IPOLICYTARGET_IID_STR "b15e7f1b-38f5-45e8-9d71-f4c47ec3b8c6"

#define NS_IPOLICYTARGET_IID \
  {0xb15e7f1b, 0x38f5, 0x45e8, \
    { 0x9d, 0x71, 0xf4, 0xc4, 0x7e, 0xc3, 0xb8, 0xc6 }}

class NS_NO_VTABLE nsIPolicyTarget : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IPOLICYTARGET_IID)

  /**
   * Setup a listener that is to be notified when the policy location 
   * becomes available
   *
   * @param aListener ->
   */
  /* void setupPolicyListener (in nsIPolicyListener aListener); */
  NS_IMETHOD SetupPolicyListener(nsIPolicyListener *aListener) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOLICYTARGET \
  NS_IMETHOD SetupPolicyListener(nsIPolicyListener *aListener); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOLICYTARGET(_to) \
  NS_IMETHOD SetupPolicyListener(nsIPolicyListener *aListener) { return _to SetupPolicyListener(aListener); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOLICYTARGET(_to) \
  NS_IMETHOD SetupPolicyListener(nsIPolicyListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetupPolicyListener(aListener); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPolicyTarget : public nsIPolicyTarget
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOLICYTARGET

  nsPolicyTarget();

private:
  ~nsPolicyTarget();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPolicyTarget, nsIPolicyTarget)

nsPolicyTarget::nsPolicyTarget()
{
  /* member initializers and constructor code */
}

nsPolicyTarget::~nsPolicyTarget()
{
  /* destructor code */
}

/* void setupPolicyListener (in nsIPolicyListener aListener); */
NS_IMETHODIMP nsPolicyTarget::SetupPolicyListener(nsIPolicyListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPolicyTarget_h__ */
