/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIIncomingServerListener.idl
 */

#ifndef __gen_nsIIncomingServerListener_h__
#define __gen_nsIIncomingServerListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgIncomingServer_h__
#include "nsIMsgIncomingServer.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIIncomingServerListener */
#define NS_IINCOMINGSERVERLISTENER_IID_STR "e6b64b86-90cb-11d3-8b02-0060b0fc04d2"

#define NS_IINCOMINGSERVERLISTENER_IID \
  {0xe6b64b86, 0x90cb, 0x11d3, \
    { 0x8b, 0x02, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xd2 }}

class NS_NO_VTABLE nsIIncomingServerListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IINCOMINGSERVERLISTENER_IID)

  /* void onServerLoaded (in nsIMsgIncomingServer server); */
  NS_IMETHOD OnServerLoaded(nsIMsgIncomingServer *server) = 0;

  /* void onServerUnloaded (in nsIMsgIncomingServer server); */
  NS_IMETHOD OnServerUnloaded(nsIMsgIncomingServer *server) = 0;

  /* void onServerChanged (in nsIMsgIncomingServer server); */
  NS_IMETHOD OnServerChanged(nsIMsgIncomingServer *server) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIINCOMINGSERVERLISTENER \
  NS_IMETHOD OnServerLoaded(nsIMsgIncomingServer *server); \
  NS_IMETHOD OnServerUnloaded(nsIMsgIncomingServer *server); \
  NS_IMETHOD OnServerChanged(nsIMsgIncomingServer *server); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIINCOMINGSERVERLISTENER(_to) \
  NS_IMETHOD OnServerLoaded(nsIMsgIncomingServer *server) { return _to OnServerLoaded(server); } \
  NS_IMETHOD OnServerUnloaded(nsIMsgIncomingServer *server) { return _to OnServerUnloaded(server); } \
  NS_IMETHOD OnServerChanged(nsIMsgIncomingServer *server) { return _to OnServerChanged(server); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIINCOMINGSERVERLISTENER(_to) \
  NS_IMETHOD OnServerLoaded(nsIMsgIncomingServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnServerLoaded(server); } \
  NS_IMETHOD OnServerUnloaded(nsIMsgIncomingServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnServerUnloaded(server); } \
  NS_IMETHOD OnServerChanged(nsIMsgIncomingServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnServerChanged(server); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsIncomingServerListener : public nsIIncomingServerListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIINCOMINGSERVERLISTENER

  nsIncomingServerListener();

private:
  ~nsIncomingServerListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsIncomingServerListener, nsIIncomingServerListener)

nsIncomingServerListener::nsIncomingServerListener()
{
  /* member initializers and constructor code */
}

nsIncomingServerListener::~nsIncomingServerListener()
{
  /* destructor code */
}

/* void onServerLoaded (in nsIMsgIncomingServer server); */
NS_IMETHODIMP nsIncomingServerListener::OnServerLoaded(nsIMsgIncomingServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onServerUnloaded (in nsIMsgIncomingServer server); */
NS_IMETHODIMP nsIncomingServerListener::OnServerUnloaded(nsIMsgIncomingServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onServerChanged (in nsIMsgIncomingServer server); */
NS_IMETHODIMP nsIncomingServerListener::OnServerChanged(nsIMsgIncomingServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIIncomingServerListener_h__ */
