/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIWalletEditor.idl
 */

#ifndef __gen_nsIWalletEditor_h__
#define __gen_nsIWalletEditor_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindowInternal; /* forward declaration */


/* starting interface:    nsIWalletEditor */
#define NS_IWALLETEDITOR_IID_STR "0a904580-1c88-11d3-aba9-0080c787ad96"

#define NS_IWALLETEDITOR_IID \
  {0x0a904580, 0x1c88, 0x11d3, \
    { 0xab, 0xa9, 0x00, 0x80, 0xc7, 0x87, 0xad, 0x96 }}

class NS_NO_VTABLE nsIWalletEditor : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IWALLETEDITOR_IID)

  /* void SetValue (in wstring aValue, in nsIDOMWindowInternal win); */
  NS_IMETHOD SetValue(const PRUnichar *aValue, nsIDOMWindowInternal *win) = 0;

  /* wstring GetValue (); */
  NS_IMETHOD GetValue(PRUnichar **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIWALLETEDITOR \
  NS_IMETHOD SetValue(const PRUnichar *aValue, nsIDOMWindowInternal *win); \
  NS_IMETHOD GetValue(PRUnichar **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIWALLETEDITOR(_to) \
  NS_IMETHOD SetValue(const PRUnichar *aValue, nsIDOMWindowInternal *win) { return _to SetValue(aValue, win); } \
  NS_IMETHOD GetValue(PRUnichar **_retval) { return _to GetValue(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIWALLETEDITOR(_to) \
  NS_IMETHOD SetValue(const PRUnichar *aValue, nsIDOMWindowInternal *win) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValue(aValue, win); } \
  NS_IMETHOD GetValue(PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValue(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsWalletEditor : public nsIWalletEditor
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIWALLETEDITOR

  nsWalletEditor();

private:
  ~nsWalletEditor();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsWalletEditor, nsIWalletEditor)

nsWalletEditor::nsWalletEditor()
{
  /* member initializers and constructor code */
}

nsWalletEditor::~nsWalletEditor()
{
  /* destructor code */
}

/* void SetValue (in wstring aValue, in nsIDOMWindowInternal win); */
NS_IMETHODIMP nsWalletEditor::SetValue(const PRUnichar *aValue, nsIDOMWindowInternal *win)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetValue (); */
NS_IMETHODIMP nsWalletEditor::GetValue(PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

// {F86A2E60-1C6A-11d3-ABA9-0080C787AD96}
#define NS_WALLETEDITOR_CID \
{ 0xf86a2e60, 0x1c6a, 0x11d3, { 0xab, 0xa9, 0x0, 0x80, 0xc7, 0x87, 0xad, 0x96 } }

#endif /* __gen_nsIWalletEditor_h__ */
