/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgParseMailMsgState.idl
 */

#ifndef __gen_nsIMsgParseMailMsgState_h__
#define __gen_nsIMsgParseMailMsgState_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDatabase; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

class nsIOFileStream; /* forward declaration */

#include "nsIMsgDatabase.h"
#include "nsIMsgHdr.h"
typedef PRInt32 nsMailboxParseState;


/* starting interface:    nsIMsgParseMailMsgState */
#define NS_IMSGPARSEMAILMSGSTATE_IID_STR "0cc23170-1459-11d3-8097-006008128c4e"

#define NS_IMSGPARSEMAILMSGSTATE_IID \
  {0x0cc23170, 0x1459, 0x11d3, \
    { 0x80, 0x97, 0x00, 0x60, 0x08, 0x12, 0x8c, 0x4e }}

class NS_NO_VTABLE nsIMsgParseMailMsgState : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGPARSEMAILMSGSTATE_IID)

  /* attribute unsigned long envelopePos; */
  NS_IMETHOD GetEnvelopePos(PRUint32 *aEnvelopePos) = 0;
  NS_IMETHOD SetEnvelopePos(PRUint32 aEnvelopePos) = 0;

  /* void SetMailDB (in nsIMsgDatabase aDatabase); */
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase) = 0;

  /* void setDBFolderStream (in nsIOFileStream fileStream); */
  NS_IMETHOD SetDBFolderStream(nsIOFileStream *fileStream) = 0;

  /* void Clear (); */
  NS_IMETHOD Clear(void) = 0;

  /* void ParseAFolderLine (in string line, in unsigned long lineLength); */
  NS_IMETHOD ParseAFolderLine(const char *line, PRUint32 lineLength) = 0;

  /* nsIMsgDBHdr GetNewMsgHdr (); */
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr **_retval) = 0;

  /* void FinishHeader (); */
  NS_IMETHOD FinishHeader(void) = 0;

  /* long GetAllHeaders (out string headers); */
  NS_IMETHOD GetAllHeaders(char **headers, PRInt32 *_retval) = 0;

  /* readonly attribute string headers; */
  NS_IMETHOD GetHeaders(char * *aHeaders) = 0;

  /* attribute nsMailboxParseState state; */
  NS_IMETHOD GetState(nsMailboxParseState *aState) = 0;
  NS_IMETHOD SetState(nsMailboxParseState aState) = 0;

  enum { ParseEnvelopeState = 0 };

  enum { ParseHeadersState = 1 };

  enum { ParseBodyState = 2 };

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPARSEMAILMSGSTATE \
  NS_IMETHOD GetEnvelopePos(PRUint32 *aEnvelopePos); \
  NS_IMETHOD SetEnvelopePos(PRUint32 aEnvelopePos); \
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase); \
  NS_IMETHOD SetDBFolderStream(nsIOFileStream *fileStream); \
  NS_IMETHOD Clear(void); \
  NS_IMETHOD ParseAFolderLine(const char *line, PRUint32 lineLength); \
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr **_retval); \
  NS_IMETHOD FinishHeader(void); \
  NS_IMETHOD GetAllHeaders(char **headers, PRInt32 *_retval); \
  NS_IMETHOD GetHeaders(char * *aHeaders); \
  NS_IMETHOD GetState(nsMailboxParseState *aState); \
  NS_IMETHOD SetState(nsMailboxParseState aState); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPARSEMAILMSGSTATE(_to) \
  NS_IMETHOD GetEnvelopePos(PRUint32 *aEnvelopePos) { return _to GetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetEnvelopePos(PRUint32 aEnvelopePos) { return _to SetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase) { return _to SetMailDB(aDatabase); } \
  NS_IMETHOD SetDBFolderStream(nsIOFileStream *fileStream) { return _to SetDBFolderStream(fileStream); } \
  NS_IMETHOD Clear(void) { return _to Clear(); } \
  NS_IMETHOD ParseAFolderLine(const char *line, PRUint32 lineLength) { return _to ParseAFolderLine(line, lineLength); } \
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr **_retval) { return _to GetNewMsgHdr(_retval); } \
  NS_IMETHOD FinishHeader(void) { return _to FinishHeader(); } \
  NS_IMETHOD GetAllHeaders(char **headers, PRInt32 *_retval) { return _to GetAllHeaders(headers, _retval); } \
  NS_IMETHOD GetHeaders(char * *aHeaders) { return _to GetHeaders(aHeaders); } \
  NS_IMETHOD GetState(nsMailboxParseState *aState) { return _to GetState(aState); } \
  NS_IMETHOD SetState(nsMailboxParseState aState) { return _to SetState(aState); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPARSEMAILMSGSTATE(_to) \
  NS_IMETHOD GetEnvelopePos(PRUint32 *aEnvelopePos) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetEnvelopePos(PRUint32 aEnvelopePos) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMailDB(aDatabase); } \
  NS_IMETHOD SetDBFolderStream(nsIOFileStream *fileStream) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDBFolderStream(fileStream); } \
  NS_IMETHOD Clear(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Clear(); } \
  NS_IMETHOD ParseAFolderLine(const char *line, PRUint32 lineLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->ParseAFolderLine(line, lineLength); } \
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewMsgHdr(_retval); } \
  NS_IMETHOD FinishHeader(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->FinishHeader(); } \
  NS_IMETHOD GetAllHeaders(char **headers, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAllHeaders(headers, _retval); } \
  NS_IMETHOD GetHeaders(char * *aHeaders) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHeaders(aHeaders); } \
  NS_IMETHOD GetState(nsMailboxParseState *aState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetState(aState); } \
  NS_IMETHOD SetState(nsMailboxParseState aState) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetState(aState); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgParseMailMsgState : public nsIMsgParseMailMsgState
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPARSEMAILMSGSTATE

  nsMsgParseMailMsgState();

private:
  ~nsMsgParseMailMsgState();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgParseMailMsgState, nsIMsgParseMailMsgState)

nsMsgParseMailMsgState::nsMsgParseMailMsgState()
{
  /* member initializers and constructor code */
}

nsMsgParseMailMsgState::~nsMsgParseMailMsgState()
{
  /* destructor code */
}

/* attribute unsigned long envelopePos; */
NS_IMETHODIMP nsMsgParseMailMsgState::GetEnvelopePos(PRUint32 *aEnvelopePos)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgParseMailMsgState::SetEnvelopePos(PRUint32 aEnvelopePos)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetMailDB (in nsIMsgDatabase aDatabase); */
NS_IMETHODIMP nsMsgParseMailMsgState::SetMailDB(nsIMsgDatabase *aDatabase)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setDBFolderStream (in nsIOFileStream fileStream); */
NS_IMETHODIMP nsMsgParseMailMsgState::SetDBFolderStream(nsIOFileStream *fileStream)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void Clear (); */
NS_IMETHODIMP nsMsgParseMailMsgState::Clear()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ParseAFolderLine (in string line, in unsigned long lineLength); */
NS_IMETHODIMP nsMsgParseMailMsgState::ParseAFolderLine(const char *line, PRUint32 lineLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgDBHdr GetNewMsgHdr (); */
NS_IMETHODIMP nsMsgParseMailMsgState::GetNewMsgHdr(nsIMsgDBHdr **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void FinishHeader (); */
NS_IMETHODIMP nsMsgParseMailMsgState::FinishHeader()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetAllHeaders (out string headers); */
NS_IMETHODIMP nsMsgParseMailMsgState::GetAllHeaders(char **headers, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string headers; */
NS_IMETHODIMP nsMsgParseMailMsgState::GetHeaders(char * *aHeaders)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMailboxParseState state; */
NS_IMETHODIMP nsMsgParseMailMsgState::GetState(nsMailboxParseState *aState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgParseMailMsgState::SetState(nsMailboxParseState aState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgParseMailMsgState_h__ */
