/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsITypeAheadFind.idl
 */

#ifndef __gen_nsITypeAheadFind_h__
#define __gen_nsITypeAheadFind_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_domstubs_h__
#include "domstubs.h"
#endif

#ifndef __gen_nsISupportsPrimitives_h__
#include "nsISupportsPrimitives.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
  #include "nsIDOMEvent.h"
  #define NS_TYPEAHEADFIND_CID \
    {0x46590685, 0xbc00, 0x4aac, {0xab, 0xed, 0x2c, 0x10, 0xa5, 0xb9, 0x45, 0xa4}}
  #define NS_TYPEAHEADFIND_CONTRACTID "@mozilla.org/typeaheadfind;1"
class nsIDOMEvent; /* forward declaration */


/* starting interface:    nsITypeAheadFind */
#define NS_ITYPEAHEADFIND_IID_STR "ad1c62cc-72f4-4c5b-be78-503854f9e0d8"

#define NS_ITYPEAHEADFIND_IID \
  {0xad1c62cc, 0x72f4, 0x4c5b, \
    { 0xbe, 0x78, 0x50, 0x38, 0x54, 0xf9, 0xe0, 0xd8 }}

class NS_NO_VTABLE nsITypeAheadFind : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ITYPEAHEADFIND_IID)

  /** Is type ahead find mode currently on? */
  /* readonly attribute boolean isActive; */
  NS_IMETHOD GetIsActive(PRBool *aIsActive) = 0;

  /** Manually start type ahead find mode */
  /* void startNewFind (in nsIDOMWindow aWindow, in boolean aLinksOnly); */
  NS_IMETHOD StartNewFind(nsIDOMWindow *aWindow, PRBool aLinksOnly) = 0;

  /** Manually cancel type ahead find mode */
  /* void cancelFind (); */
  NS_IMETHOD CancelFind(void) = 0;

  /**
    * Will find as you type start automatically if the user
    * types with the focus on page content other than a textfield or select?
    * If autostart is off, the startNewFind() method can be used to enact
    * type ahead find, as well as cmd_findTypeLinks or cmd_findTypeText.
    */
  /* void setAutoStart (in nsIDOMWindow aWindow, in boolean aIsAutoStartOn); */
  NS_IMETHOD SetAutoStart(nsIDOMWindow *aWindow, PRBool aIsAutoStartOn) = 0;

  /* boolean getAutoStart (in nsIDOMWindow aWindow); */
  NS_IMETHOD GetAutoStart(nsIDOMWindow *aWindow, PRBool *_retval) = 0;

  /**
    * Find next recurrence if typeaheadfind was the last used find, 
    * as opposed to regular find. Returns false in nsISupportsPRBool if we
    * don't handle the request.
    */
  /* void findNext (in boolean aReverse, in nsISupportsInterfacePointer aCallerWindowSupports); */
  NS_IMETHOD FindNext(PRBool aReverse, nsISupportsInterfacePointer *aCallerWindowSupports) = 0;

  /* boolean backOneChar (); */
  NS_IMETHOD BackOneChar(PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSITYPEAHEADFIND \
  NS_IMETHOD GetIsActive(PRBool *aIsActive); \
  NS_IMETHOD StartNewFind(nsIDOMWindow *aWindow, PRBool aLinksOnly); \
  NS_IMETHOD CancelFind(void); \
  NS_IMETHOD SetAutoStart(nsIDOMWindow *aWindow, PRBool aIsAutoStartOn); \
  NS_IMETHOD GetAutoStart(nsIDOMWindow *aWindow, PRBool *_retval); \
  NS_IMETHOD FindNext(PRBool aReverse, nsISupportsInterfacePointer *aCallerWindowSupports); \
  NS_IMETHOD BackOneChar(PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSITYPEAHEADFIND(_to) \
  NS_IMETHOD GetIsActive(PRBool *aIsActive) { return _to GetIsActive(aIsActive); } \
  NS_IMETHOD StartNewFind(nsIDOMWindow *aWindow, PRBool aLinksOnly) { return _to StartNewFind(aWindow, aLinksOnly); } \
  NS_IMETHOD CancelFind(void) { return _to CancelFind(); } \
  NS_IMETHOD SetAutoStart(nsIDOMWindow *aWindow, PRBool aIsAutoStartOn) { return _to SetAutoStart(aWindow, aIsAutoStartOn); } \
  NS_IMETHOD GetAutoStart(nsIDOMWindow *aWindow, PRBool *_retval) { return _to GetAutoStart(aWindow, _retval); } \
  NS_IMETHOD FindNext(PRBool aReverse, nsISupportsInterfacePointer *aCallerWindowSupports) { return _to FindNext(aReverse, aCallerWindowSupports); } \
  NS_IMETHOD BackOneChar(PRBool *_retval) { return _to BackOneChar(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSITYPEAHEADFIND(_to) \
  NS_IMETHOD GetIsActive(PRBool *aIsActive) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsActive(aIsActive); } \
  NS_IMETHOD StartNewFind(nsIDOMWindow *aWindow, PRBool aLinksOnly) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartNewFind(aWindow, aLinksOnly); } \
  NS_IMETHOD CancelFind(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CancelFind(); } \
  NS_IMETHOD SetAutoStart(nsIDOMWindow *aWindow, PRBool aIsAutoStartOn) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAutoStart(aWindow, aIsAutoStartOn); } \
  NS_IMETHOD GetAutoStart(nsIDOMWindow *aWindow, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAutoStart(aWindow, _retval); } \
  NS_IMETHOD FindNext(PRBool aReverse, nsISupportsInterfacePointer *aCallerWindowSupports) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindNext(aReverse, aCallerWindowSupports); } \
  NS_IMETHOD BackOneChar(PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->BackOneChar(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsTypeAheadFind : public nsITypeAheadFind
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSITYPEAHEADFIND

  nsTypeAheadFind();

private:
  ~nsTypeAheadFind();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsTypeAheadFind, nsITypeAheadFind)

nsTypeAheadFind::nsTypeAheadFind()
{
  /* member initializers and constructor code */
}

nsTypeAheadFind::~nsTypeAheadFind()
{
  /* destructor code */
}

/* readonly attribute boolean isActive; */
NS_IMETHODIMP nsTypeAheadFind::GetIsActive(PRBool *aIsActive)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void startNewFind (in nsIDOMWindow aWindow, in boolean aLinksOnly); */
NS_IMETHODIMP nsTypeAheadFind::StartNewFind(nsIDOMWindow *aWindow, PRBool aLinksOnly)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void cancelFind (); */
NS_IMETHODIMP nsTypeAheadFind::CancelFind()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setAutoStart (in nsIDOMWindow aWindow, in boolean aIsAutoStartOn); */
NS_IMETHODIMP nsTypeAheadFind::SetAutoStart(nsIDOMWindow *aWindow, PRBool aIsAutoStartOn)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getAutoStart (in nsIDOMWindow aWindow); */
NS_IMETHODIMP nsTypeAheadFind::GetAutoStart(nsIDOMWindow *aWindow, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void findNext (in boolean aReverse, in nsISupportsInterfacePointer aCallerWindowSupports); */
NS_IMETHODIMP nsTypeAheadFind::FindNext(PRBool aReverse, nsISupportsInterfacePointer *aCallerWindowSupports)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean backOneChar (); */
NS_IMETHODIMP nsTypeAheadFind::BackOneChar(PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsITypeAheadFind_h__ */
