/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Srilatha Moturi <srilatha@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsILocalFile.idl"

/**
 * This interface provides support for getting 4.x profile information
 * This interface can be used to get the existing 4.x profiles
 * and for getting the mail directory for the profile.
 * 
 */
[scriptable, uuid(c66c1060-2bdc-11d6-92a0-0010a4b26cda)]
interface nsIComm4xProfile: nsISupports {
   /**
    *  Parses the 4.x registry file and returns a list of profiles. 
    */

   void getProfileList(out unsigned long length, [array, size_is(length), retval] out wstring selectList); 
   
   /**
    *  Searches the preferences file of the given profile for the pref mail.directory
    *  If the pref does not exist it, returns the default value.
    *  @param profileName  name of the profile in the profiles array 
    *  @return             The path to the mail directory for the profile with the name profileName
    *   
    */
   wstring getMailDir(in wstring profileName);
};
