/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMailboxSpec.idl
 */

#ifndef __gen_nsIMailboxSpec_h__
#define __gen_nsIMailboxSpec_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIImapFlagAndUidState_h__
#include "nsIImapFlagAndUidState.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMAPNamespace; /* forward declaration */


/* starting interface:    nsIMailboxSpec */
#define NS_IMAILBOXSPEC_IID_STR "76cbfa2e-c7f2-11d3-a54e-0060b0fc04b7"

#define NS_IMAILBOXSPEC_IID \
  {0x76cbfa2e, 0xc7f2, 0x11d3, \
    { 0xa5, 0x4e, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xb7 }}

class NS_NO_VTABLE nsIMailboxSpec : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMAILBOXSPEC_IID)

  /* attribute long folder_UIDVALIDITY; */
  NS_IMETHOD GetFolder_UIDVALIDITY(PRInt32 *aFolder_UIDVALIDITY) = 0;
  NS_IMETHOD SetFolder_UIDVALIDITY(PRInt32 aFolder_UIDVALIDITY) = 0;

  /* attribute long numMessages; */
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages) = 0;
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages) = 0;

  /* attribute long numUnseenMessages; */
  NS_IMETHOD GetNumUnseenMessages(PRInt32 *aNumUnseenMessages) = 0;
  NS_IMETHOD SetNumUnseenMessages(PRInt32 aNumUnseenMessages) = 0;

  /* attribute long numRecentMessages; */
  NS_IMETHOD GetNumRecentMessages(PRInt32 *aNumRecentMessages) = 0;
  NS_IMETHOD SetNumRecentMessages(PRInt32 aNumRecentMessages) = 0;

  /* attribute unsigned long box_flags; */
  NS_IMETHOD GetBox_flags(PRUint32 *aBox_flags) = 0;
  NS_IMETHOD SetBox_flags(PRUint32 aBox_flags) = 0;

  /* attribute unsigned long supportedUserFlags; */
  NS_IMETHOD GetSupportedUserFlags(PRUint32 *aSupportedUserFlags) = 0;
  NS_IMETHOD SetSupportedUserFlags(PRUint32 aSupportedUserFlags) = 0;

  /* attribute string allocatedPathName; */
  NS_IMETHOD GetAllocatedPathName(char * *aAllocatedPathName) = 0;
  NS_IMETHOD SetAllocatedPathName(const char * aAllocatedPathName) = 0;

  /* attribute wstring unicharPathName; */
  NS_IMETHOD GetUnicharPathName(PRUnichar * *aUnicharPathName) = 0;
  NS_IMETHOD SetUnicharPathName(const PRUnichar * aUnicharPathName) = 0;

  /* attribute char hierarchySeparator; */
  NS_IMETHOD GetHierarchySeparator(char *aHierarchySeparator) = 0;
  NS_IMETHOD SetHierarchySeparator(char aHierarchySeparator) = 0;

  /* attribute string hostName; */
  NS_IMETHOD GetHostName(char * *aHostName) = 0;
  NS_IMETHOD SetHostName(const char * aHostName) = 0;

  /* attribute nsIImapFlagAndUidState flagState; */
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState) = 0;
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState * aFlagState) = 0;

  /* attribute boolean folderSelected; */
  NS_IMETHOD GetFolderSelected(PRBool *aFolderSelected) = 0;
  NS_IMETHOD SetFolderSelected(PRBool aFolderSelected) = 0;

  /* attribute boolean discoveredFromLsub; */
  NS_IMETHOD GetDiscoveredFromLsub(PRBool *aDiscoveredFromLsub) = 0;
  NS_IMETHOD SetDiscoveredFromLsub(PRBool aDiscoveredFromLsub) = 0;

  /* attribute boolean onlineVerified; */
  NS_IMETHOD GetOnlineVerified(PRBool *aOnlineVerified) = 0;
  NS_IMETHOD SetOnlineVerified(PRBool aOnlineVerified) = 0;

  /* [noscript] attribute nsIMAPNamespace namespaceForFolder; */
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder) = 0;
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace * aNamespaceForFolder) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMAILBOXSPEC \
  NS_IMETHOD GetFolder_UIDVALIDITY(PRInt32 *aFolder_UIDVALIDITY); \
  NS_IMETHOD SetFolder_UIDVALIDITY(PRInt32 aFolder_UIDVALIDITY); \
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages); \
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages); \
  NS_IMETHOD GetNumUnseenMessages(PRInt32 *aNumUnseenMessages); \
  NS_IMETHOD SetNumUnseenMessages(PRInt32 aNumUnseenMessages); \
  NS_IMETHOD GetNumRecentMessages(PRInt32 *aNumRecentMessages); \
  NS_IMETHOD SetNumRecentMessages(PRInt32 aNumRecentMessages); \
  NS_IMETHOD GetBox_flags(PRUint32 *aBox_flags); \
  NS_IMETHOD SetBox_flags(PRUint32 aBox_flags); \
  NS_IMETHOD GetSupportedUserFlags(PRUint32 *aSupportedUserFlags); \
  NS_IMETHOD SetSupportedUserFlags(PRUint32 aSupportedUserFlags); \
  NS_IMETHOD GetAllocatedPathName(char * *aAllocatedPathName); \
  NS_IMETHOD SetAllocatedPathName(const char * aAllocatedPathName); \
  NS_IMETHOD GetUnicharPathName(PRUnichar * *aUnicharPathName); \
  NS_IMETHOD SetUnicharPathName(const PRUnichar * aUnicharPathName); \
  NS_IMETHOD GetHierarchySeparator(char *aHierarchySeparator); \
  NS_IMETHOD SetHierarchySeparator(char aHierarchySeparator); \
  NS_IMETHOD GetHostName(char * *aHostName); \
  NS_IMETHOD SetHostName(const char * aHostName); \
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState); \
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState * aFlagState); \
  NS_IMETHOD GetFolderSelected(PRBool *aFolderSelected); \
  NS_IMETHOD SetFolderSelected(PRBool aFolderSelected); \
  NS_IMETHOD GetDiscoveredFromLsub(PRBool *aDiscoveredFromLsub); \
  NS_IMETHOD SetDiscoveredFromLsub(PRBool aDiscoveredFromLsub); \
  NS_IMETHOD GetOnlineVerified(PRBool *aOnlineVerified); \
  NS_IMETHOD SetOnlineVerified(PRBool aOnlineVerified); \
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder); \
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace * aNamespaceForFolder); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMAILBOXSPEC(_to) \
  NS_IMETHOD GetFolder_UIDVALIDITY(PRInt32 *aFolder_UIDVALIDITY) { return _to GetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD SetFolder_UIDVALIDITY(PRInt32 aFolder_UIDVALIDITY) { return _to SetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages) { return _to GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages) { return _to SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetNumUnseenMessages(PRInt32 *aNumUnseenMessages) { return _to GetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD SetNumUnseenMessages(PRInt32 aNumUnseenMessages) { return _to SetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD GetNumRecentMessages(PRInt32 *aNumRecentMessages) { return _to GetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD SetNumRecentMessages(PRInt32 aNumRecentMessages) { return _to SetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD GetBox_flags(PRUint32 *aBox_flags) { return _to GetBox_flags(aBox_flags); } \
  NS_IMETHOD SetBox_flags(PRUint32 aBox_flags) { return _to SetBox_flags(aBox_flags); } \
  NS_IMETHOD GetSupportedUserFlags(PRUint32 *aSupportedUserFlags) { return _to GetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD SetSupportedUserFlags(PRUint32 aSupportedUserFlags) { return _to SetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD GetAllocatedPathName(char * *aAllocatedPathName) { return _to GetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD SetAllocatedPathName(const char * aAllocatedPathName) { return _to SetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD GetUnicharPathName(PRUnichar * *aUnicharPathName) { return _to GetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD SetUnicharPathName(const PRUnichar * aUnicharPathName) { return _to SetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD GetHierarchySeparator(char *aHierarchySeparator) { return _to GetHierarchySeparator(aHierarchySeparator); } \
  NS_IMETHOD SetHierarchySeparator(char aHierarchySeparator) { return _to SetHierarchySeparator(aHierarchySeparator); } \
  NS_IMETHOD GetHostName(char * *aHostName) { return _to GetHostName(aHostName); } \
  NS_IMETHOD SetHostName(const char * aHostName) { return _to SetHostName(aHostName); } \
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState) { return _to GetFlagState(aFlagState); } \
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState * aFlagState) { return _to SetFlagState(aFlagState); } \
  NS_IMETHOD GetFolderSelected(PRBool *aFolderSelected) { return _to GetFolderSelected(aFolderSelected); } \
  NS_IMETHOD SetFolderSelected(PRBool aFolderSelected) { return _to SetFolderSelected(aFolderSelected); } \
  NS_IMETHOD GetDiscoveredFromLsub(PRBool *aDiscoveredFromLsub) { return _to GetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD SetDiscoveredFromLsub(PRBool aDiscoveredFromLsub) { return _to SetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD GetOnlineVerified(PRBool *aOnlineVerified) { return _to GetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD SetOnlineVerified(PRBool aOnlineVerified) { return _to SetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder) { return _to GetNamespaceForFolder(aNamespaceForFolder); } \
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace * aNamespaceForFolder) { return _to SetNamespaceForFolder(aNamespaceForFolder); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMAILBOXSPEC(_to) \
  NS_IMETHOD GetFolder_UIDVALIDITY(PRInt32 *aFolder_UIDVALIDITY) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD SetFolder_UIDVALIDITY(PRInt32 aFolder_UIDVALIDITY) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD GetNumMessages(PRInt32 *aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(PRInt32 aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetNumUnseenMessages(PRInt32 *aNumUnseenMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD SetNumUnseenMessages(PRInt32 aNumUnseenMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD GetNumRecentMessages(PRInt32 *aNumRecentMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD SetNumRecentMessages(PRInt32 aNumRecentMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD GetBox_flags(PRUint32 *aBox_flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBox_flags(aBox_flags); } \
  NS_IMETHOD SetBox_flags(PRUint32 aBox_flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBox_flags(aBox_flags); } \
  NS_IMETHOD GetSupportedUserFlags(PRUint32 *aSupportedUserFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD SetSupportedUserFlags(PRUint32 aSupportedUserFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD GetAllocatedPathName(char * *aAllocatedPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD SetAllocatedPathName(const char * aAllocatedPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD GetUnicharPathName(PRUnichar * *aUnicharPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD SetUnicharPathName(const PRUnichar * aUnicharPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD GetHierarchySeparator(char *aHierarchySeparator) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHierarchySeparator(aHierarchySeparator); } \
  NS_IMETHOD SetHierarchySeparator(char aHierarchySeparator) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHierarchySeparator(aHierarchySeparator); } \
  NS_IMETHOD GetHostName(char * *aHostName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHostName(aHostName); } \
  NS_IMETHOD SetHostName(const char * aHostName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHostName(aHostName); } \
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFlagState(aFlagState); } \
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState * aFlagState) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFlagState(aFlagState); } \
  NS_IMETHOD GetFolderSelected(PRBool *aFolderSelected) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderSelected(aFolderSelected); } \
  NS_IMETHOD SetFolderSelected(PRBool aFolderSelected) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderSelected(aFolderSelected); } \
  NS_IMETHOD GetDiscoveredFromLsub(PRBool *aDiscoveredFromLsub) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD SetDiscoveredFromLsub(PRBool aDiscoveredFromLsub) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD GetOnlineVerified(PRBool *aOnlineVerified) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD SetOnlineVerified(PRBool aOnlineVerified) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNamespaceForFolder(aNamespaceForFolder); } \
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace * aNamespaceForFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNamespaceForFolder(aNamespaceForFolder); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMailboxSpec : public nsIMailboxSpec
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMAILBOXSPEC

  nsMailboxSpec();

private:
  ~nsMailboxSpec();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMailboxSpec, nsIMailboxSpec)

nsMailboxSpec::nsMailboxSpec()
{
  /* member initializers and constructor code */
}

nsMailboxSpec::~nsMailboxSpec()
{
  /* destructor code */
}

/* attribute long folder_UIDVALIDITY; */
NS_IMETHODIMP nsMailboxSpec::GetFolder_UIDVALIDITY(PRInt32 *aFolder_UIDVALIDITY)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetFolder_UIDVALIDITY(PRInt32 aFolder_UIDVALIDITY)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numMessages; */
NS_IMETHODIMP nsMailboxSpec::GetNumMessages(PRInt32 *aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNumMessages(PRInt32 aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numUnseenMessages; */
NS_IMETHODIMP nsMailboxSpec::GetNumUnseenMessages(PRInt32 *aNumUnseenMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNumUnseenMessages(PRInt32 aNumUnseenMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numRecentMessages; */
NS_IMETHODIMP nsMailboxSpec::GetNumRecentMessages(PRInt32 *aNumRecentMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNumRecentMessages(PRInt32 aNumRecentMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long box_flags; */
NS_IMETHODIMP nsMailboxSpec::GetBox_flags(PRUint32 *aBox_flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetBox_flags(PRUint32 aBox_flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long supportedUserFlags; */
NS_IMETHODIMP nsMailboxSpec::GetSupportedUserFlags(PRUint32 *aSupportedUserFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetSupportedUserFlags(PRUint32 aSupportedUserFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string allocatedPathName; */
NS_IMETHODIMP nsMailboxSpec::GetAllocatedPathName(char * *aAllocatedPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetAllocatedPathName(const char * aAllocatedPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute wstring unicharPathName; */
NS_IMETHODIMP nsMailboxSpec::GetUnicharPathName(PRUnichar * *aUnicharPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetUnicharPathName(const PRUnichar * aUnicharPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute char hierarchySeparator; */
NS_IMETHODIMP nsMailboxSpec::GetHierarchySeparator(char *aHierarchySeparator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetHierarchySeparator(char aHierarchySeparator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string hostName; */
NS_IMETHODIMP nsMailboxSpec::GetHostName(char * *aHostName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetHostName(const char * aHostName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIImapFlagAndUidState flagState; */
NS_IMETHODIMP nsMailboxSpec::GetFlagState(nsIImapFlagAndUidState * *aFlagState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetFlagState(nsIImapFlagAndUidState * aFlagState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean folderSelected; */
NS_IMETHODIMP nsMailboxSpec::GetFolderSelected(PRBool *aFolderSelected)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetFolderSelected(PRBool aFolderSelected)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean discoveredFromLsub; */
NS_IMETHODIMP nsMailboxSpec::GetDiscoveredFromLsub(PRBool *aDiscoveredFromLsub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetDiscoveredFromLsub(PRBool aDiscoveredFromLsub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean onlineVerified; */
NS_IMETHODIMP nsMailboxSpec::GetOnlineVerified(PRBool *aOnlineVerified)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetOnlineVerified(PRBool aOnlineVerified)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] attribute nsIMAPNamespace namespaceForFolder; */
NS_IMETHODIMP nsMailboxSpec::GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNamespaceForFolder(nsIMAPNamespace * aNamespaceForFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMailboxSpec_h__ */
