/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsISmtpServer.idl
 */

#ifndef __gen_nsISmtpServer_h__
#define __gen_nsISmtpServer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAuthPrompt; /* forward declaration */


/* starting interface:    nsISmtpServer */
#define NS_ISMTPSERVER_IID_STR "eef39b32-9050-11db-92fa-000c6e0abfac"

#define NS_ISMTPSERVER_IID \
  {0xeef39b32, 0x9050, 0x11db, \
    { 0x92, 0xfa, 0x00, 0x0c, 0x6e, 0x0a, 0xbf, 0xac }}

class NS_NO_VTABLE nsISmtpServer : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISMTPSERVER_IID)

  /* attribute string key; */
  NS_IMETHOD GetKey(char * *aKey) = 0;
  NS_IMETHOD SetKey(const char * aKey) = 0;

  /* attribute AUTF8String description; */
  NS_IMETHOD GetDescription(nsACString & aDescription) = 0;
  NS_IMETHOD SetDescription(const nsACString & aDescription) = 0;

  /* attribute string hostname; */
  NS_IMETHOD GetHostname(char * *aHostname) = 0;
  NS_IMETHOD SetHostname(const char * aHostname) = 0;

  /* attribute PRInt32 port; */
  NS_IMETHOD GetPort(PRInt32 *aPort) = 0;
  NS_IMETHOD SetPort(PRInt32 aPort) = 0;

  /* attribute string username; */
  NS_IMETHOD GetUsername(char * *aUsername) = 0;
  NS_IMETHOD SetUsername(const char * aUsername) = 0;

  /* attribute string password; */
  NS_IMETHOD GetPassword(char * *aPassword) = 0;
  NS_IMETHOD SetPassword(const char * aPassword) = 0;

  /* readonly attribute string displayname; */
  NS_IMETHOD GetDisplayname(char * *aDisplayname) = 0;

  /* attribute string redirectorType; */
  NS_IMETHOD GetRedirectorType(char * *aRedirectorType) = 0;
  NS_IMETHOD SetRedirectorType(const char * aRedirectorType) = 0;

  /* attribute long authMethod; */
  NS_IMETHOD GetAuthMethod(PRInt32 *aAuthMethod) = 0;
  NS_IMETHOD SetAuthMethod(PRInt32 aAuthMethod) = 0;

  /* readonly attribute boolean trySecAuth; */
  NS_IMETHOD GetTrySecAuth(PRBool *aTrySecAuth) = 0;

  /* attribute long trySSL; */
  NS_IMETHOD GetTrySSL(PRInt32 *aTrySSL) = 0;
  NS_IMETHOD SetTrySSL(PRInt32 aTrySSL) = 0;

  /* readonly attribute string helloArgument; */
  NS_IMETHOD GetHelloArgument(char * *aHelloArgument) = 0;

  /* readonly attribute string serverURI; */
  NS_IMETHOD GetServerURI(char * *aServerURI) = 0;

  /* string getPasswordWithUI (in wstring promptString, in wstring promptTitle, in nsIAuthPrompt netPrompt); */
  NS_IMETHOD GetPasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **_retval) = 0;

  /* void getUsernamePasswordWithUI (in wstring promptString, in wstring promptTitle, in nsIAuthPrompt netPrompt, out string userid, out string password); */
  NS_IMETHOD GetUsernamePasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **userid, char **password) = 0;

  /* void forgetPassword (); */
  NS_IMETHOD ForgetPassword(void) = 0;

  /* void clearAllValues (); */
  NS_IMETHOD ClearAllValues(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISMTPSERVER \
  NS_IMETHOD GetKey(char * *aKey); \
  NS_IMETHOD SetKey(const char * aKey); \
  NS_IMETHOD GetDescription(nsACString & aDescription); \
  NS_IMETHOD SetDescription(const nsACString & aDescription); \
  NS_IMETHOD GetHostname(char * *aHostname); \
  NS_IMETHOD SetHostname(const char * aHostname); \
  NS_IMETHOD GetPort(PRInt32 *aPort); \
  NS_IMETHOD SetPort(PRInt32 aPort); \
  NS_IMETHOD GetUsername(char * *aUsername); \
  NS_IMETHOD SetUsername(const char * aUsername); \
  NS_IMETHOD GetPassword(char * *aPassword); \
  NS_IMETHOD SetPassword(const char * aPassword); \
  NS_IMETHOD GetDisplayname(char * *aDisplayname); \
  NS_IMETHOD GetRedirectorType(char * *aRedirectorType); \
  NS_IMETHOD SetRedirectorType(const char * aRedirectorType); \
  NS_IMETHOD GetAuthMethod(PRInt32 *aAuthMethod); \
  NS_IMETHOD SetAuthMethod(PRInt32 aAuthMethod); \
  NS_IMETHOD GetTrySecAuth(PRBool *aTrySecAuth); \
  NS_IMETHOD GetTrySSL(PRInt32 *aTrySSL); \
  NS_IMETHOD SetTrySSL(PRInt32 aTrySSL); \
  NS_IMETHOD GetHelloArgument(char * *aHelloArgument); \
  NS_IMETHOD GetServerURI(char * *aServerURI); \
  NS_IMETHOD GetPasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **_retval); \
  NS_IMETHOD GetUsernamePasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **userid, char **password); \
  NS_IMETHOD ForgetPassword(void); \
  NS_IMETHOD ClearAllValues(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISMTPSERVER(_to) \
  NS_IMETHOD GetKey(char * *aKey) { return _to GetKey(aKey); } \
  NS_IMETHOD SetKey(const char * aKey) { return _to SetKey(aKey); } \
  NS_IMETHOD GetDescription(nsACString & aDescription) { return _to GetDescription(aDescription); } \
  NS_IMETHOD SetDescription(const nsACString & aDescription) { return _to SetDescription(aDescription); } \
  NS_IMETHOD GetHostname(char * *aHostname) { return _to GetHostname(aHostname); } \
  NS_IMETHOD SetHostname(const char * aHostname) { return _to SetHostname(aHostname); } \
  NS_IMETHOD GetPort(PRInt32 *aPort) { return _to GetPort(aPort); } \
  NS_IMETHOD SetPort(PRInt32 aPort) { return _to SetPort(aPort); } \
  NS_IMETHOD GetUsername(char * *aUsername) { return _to GetUsername(aUsername); } \
  NS_IMETHOD SetUsername(const char * aUsername) { return _to SetUsername(aUsername); } \
  NS_IMETHOD GetPassword(char * *aPassword) { return _to GetPassword(aPassword); } \
  NS_IMETHOD SetPassword(const char * aPassword) { return _to SetPassword(aPassword); } \
  NS_IMETHOD GetDisplayname(char * *aDisplayname) { return _to GetDisplayname(aDisplayname); } \
  NS_IMETHOD GetRedirectorType(char * *aRedirectorType) { return _to GetRedirectorType(aRedirectorType); } \
  NS_IMETHOD SetRedirectorType(const char * aRedirectorType) { return _to SetRedirectorType(aRedirectorType); } \
  NS_IMETHOD GetAuthMethod(PRInt32 *aAuthMethod) { return _to GetAuthMethod(aAuthMethod); } \
  NS_IMETHOD SetAuthMethod(PRInt32 aAuthMethod) { return _to SetAuthMethod(aAuthMethod); } \
  NS_IMETHOD GetTrySecAuth(PRBool *aTrySecAuth) { return _to GetTrySecAuth(aTrySecAuth); } \
  NS_IMETHOD GetTrySSL(PRInt32 *aTrySSL) { return _to GetTrySSL(aTrySSL); } \
  NS_IMETHOD SetTrySSL(PRInt32 aTrySSL) { return _to SetTrySSL(aTrySSL); } \
  NS_IMETHOD GetHelloArgument(char * *aHelloArgument) { return _to GetHelloArgument(aHelloArgument); } \
  NS_IMETHOD GetServerURI(char * *aServerURI) { return _to GetServerURI(aServerURI); } \
  NS_IMETHOD GetPasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **_retval) { return _to GetPasswordWithUI(promptString, promptTitle, netPrompt, _retval); } \
  NS_IMETHOD GetUsernamePasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **userid, char **password) { return _to GetUsernamePasswordWithUI(promptString, promptTitle, netPrompt, userid, password); } \
  NS_IMETHOD ForgetPassword(void) { return _to ForgetPassword(); } \
  NS_IMETHOD ClearAllValues(void) { return _to ClearAllValues(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISMTPSERVER(_to) \
  NS_IMETHOD GetKey(char * *aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKey(aKey); } \
  NS_IMETHOD SetKey(const char * aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetKey(aKey); } \
  NS_IMETHOD GetDescription(nsACString & aDescription) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDescription(aDescription); } \
  NS_IMETHOD SetDescription(const nsACString & aDescription) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDescription(aDescription); } \
  NS_IMETHOD GetHostname(char * *aHostname) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHostname(aHostname); } \
  NS_IMETHOD SetHostname(const char * aHostname) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHostname(aHostname); } \
  NS_IMETHOD GetPort(PRInt32 *aPort) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPort(aPort); } \
  NS_IMETHOD SetPort(PRInt32 aPort) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPort(aPort); } \
  NS_IMETHOD GetUsername(char * *aUsername) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUsername(aUsername); } \
  NS_IMETHOD SetUsername(const char * aUsername) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUsername(aUsername); } \
  NS_IMETHOD GetPassword(char * *aPassword) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPassword(aPassword); } \
  NS_IMETHOD SetPassword(const char * aPassword) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPassword(aPassword); } \
  NS_IMETHOD GetDisplayname(char * *aDisplayname) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDisplayname(aDisplayname); } \
  NS_IMETHOD GetRedirectorType(char * *aRedirectorType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRedirectorType(aRedirectorType); } \
  NS_IMETHOD SetRedirectorType(const char * aRedirectorType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRedirectorType(aRedirectorType); } \
  NS_IMETHOD GetAuthMethod(PRInt32 *aAuthMethod) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAuthMethod(aAuthMethod); } \
  NS_IMETHOD SetAuthMethod(PRInt32 aAuthMethod) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAuthMethod(aAuthMethod); } \
  NS_IMETHOD GetTrySecAuth(PRBool *aTrySecAuth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTrySecAuth(aTrySecAuth); } \
  NS_IMETHOD GetTrySSL(PRInt32 *aTrySSL) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTrySSL(aTrySSL); } \
  NS_IMETHOD SetTrySSL(PRInt32 aTrySSL) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTrySSL(aTrySSL); } \
  NS_IMETHOD GetHelloArgument(char * *aHelloArgument) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHelloArgument(aHelloArgument); } \
  NS_IMETHOD GetServerURI(char * *aServerURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetServerURI(aServerURI); } \
  NS_IMETHOD GetPasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPasswordWithUI(promptString, promptTitle, netPrompt, _retval); } \
  NS_IMETHOD GetUsernamePasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **userid, char **password) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUsernamePasswordWithUI(promptString, promptTitle, netPrompt, userid, password); } \
  NS_IMETHOD ForgetPassword(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ForgetPassword(); } \
  NS_IMETHOD ClearAllValues(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearAllValues(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSmtpServer : public nsISmtpServer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISMTPSERVER

  nsSmtpServer();

private:
  ~nsSmtpServer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSmtpServer, nsISmtpServer)

nsSmtpServer::nsSmtpServer()
{
  /* member initializers and constructor code */
}

nsSmtpServer::~nsSmtpServer()
{
  /* destructor code */
}

/* attribute string key; */
NS_IMETHODIMP nsSmtpServer::GetKey(char * *aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetKey(const char * aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AUTF8String description; */
NS_IMETHODIMP nsSmtpServer::GetDescription(nsACString & aDescription)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetDescription(const nsACString & aDescription)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string hostname; */
NS_IMETHODIMP nsSmtpServer::GetHostname(char * *aHostname)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetHostname(const char * aHostname)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute PRInt32 port; */
NS_IMETHODIMP nsSmtpServer::GetPort(PRInt32 *aPort)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetPort(PRInt32 aPort)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string username; */
NS_IMETHODIMP nsSmtpServer::GetUsername(char * *aUsername)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetUsername(const char * aUsername)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string password; */
NS_IMETHODIMP nsSmtpServer::GetPassword(char * *aPassword)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetPassword(const char * aPassword)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string displayname; */
NS_IMETHODIMP nsSmtpServer::GetDisplayname(char * *aDisplayname)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string redirectorType; */
NS_IMETHODIMP nsSmtpServer::GetRedirectorType(char * *aRedirectorType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetRedirectorType(const char * aRedirectorType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long authMethod; */
NS_IMETHODIMP nsSmtpServer::GetAuthMethod(PRInt32 *aAuthMethod)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetAuthMethod(PRInt32 aAuthMethod)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean trySecAuth; */
NS_IMETHODIMP nsSmtpServer::GetTrySecAuth(PRBool *aTrySecAuth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long trySSL; */
NS_IMETHODIMP nsSmtpServer::GetTrySSL(PRInt32 *aTrySSL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpServer::SetTrySSL(PRInt32 aTrySSL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string helloArgument; */
NS_IMETHODIMP nsSmtpServer::GetHelloArgument(char * *aHelloArgument)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string serverURI; */
NS_IMETHODIMP nsSmtpServer::GetServerURI(char * *aServerURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string getPasswordWithUI (in wstring promptString, in wstring promptTitle, in nsIAuthPrompt netPrompt); */
NS_IMETHODIMP nsSmtpServer::GetPasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getUsernamePasswordWithUI (in wstring promptString, in wstring promptTitle, in nsIAuthPrompt netPrompt, out string userid, out string password); */
NS_IMETHODIMP nsSmtpServer::GetUsernamePasswordWithUI(const PRUnichar *promptString, const PRUnichar *promptTitle, nsIAuthPrompt *netPrompt, char **userid, char **password)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void forgetPassword (); */
NS_IMETHODIMP nsSmtpServer::ForgetPassword()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearAllValues (); */
NS_IMETHODIMP nsSmtpServer::ClearAllValues()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISmtpServer_h__ */
