/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgPrintEngine.idl
 */

#ifndef __gen_nsIMsgPrintEngine_h__
#define __gen_nsIMsgPrintEngine_h__


#ifndef __gen_nsrootidl_h__
#include "nsrootidl.h"
#endif

#ifndef __gen_nsIMsgStatusFeedback_h__
#include "nsIMsgStatusFeedback.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindowInternal; /* forward declaration */

class nsIPrintSettings; /* forward declaration */

class nsIObserver; /* forward declaration */

class nsIWebBrowserPrint; /* forward declaration */


/* starting interface:    nsIMsgPrintEngine */
#define NS_IMSGPRINTENGINE_IID_STR "91fd6b10-e0bc-11d3-8f97-000064657374"

#define NS_IMSGPRINTENGINE_IID \
  {0x91fd6b10, 0xe0bc, 0x11d3, \
    { 0x8f, 0x97, 0x00, 0x00, 0x64, 0x65, 0x73, 0x74 }}

class NS_NO_VTABLE nsIMsgPrintEngine : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGPRINTENGINE_IID)

  /**
     * Print/PrintPreview Msg Type
     */
  enum { MNAB_START = 0 };

  enum { MNAB_PRINT_MSG = 0 };

  enum { MNAB_PRINTPREVIEW_MSG = 1 };

  enum { MNAB_PRINT_AB_CARD = 2 };

  enum { MNAB_PRINTPREVIEW_AB_CARD = 3 };

  enum { MNAB_PRINT_ADDRBOOK = 4 };

  enum { MNAB_PRINTPREVIEW_ADDRBOOK = 5 };

  enum { MNAB_END = 6 };

  /* void setWindow (in nsIDOMWindowInternal ptr); */
  NS_IMETHOD SetWindow(nsIDOMWindowInternal *ptr) = 0;

  /* void setParentWindow (in nsIDOMWindowInternal ptr); */
  NS_IMETHOD SetParentWindow(nsIDOMWindowInternal *ptr) = 0;

  /* void showWindow (in boolean aShow); */
  NS_IMETHOD ShowWindow(PRBool aShow) = 0;

  /* void setStatusFeedback (in nsIMsgStatusFeedback feedback); */
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback) = 0;

  /* void setPrintURICount (in PRInt32 aCount); */
  NS_IMETHOD SetPrintURICount(PRInt32 aCount) = 0;

  /* void addPrintURI (in wstring aURI); */
  NS_IMETHOD AddPrintURI(const PRUnichar *aURI) = 0;

  /* void startPrintOperation (in nsIPrintSettings aPS); */
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS) = 0;

  /* void setStartupPPObserver (in nsIObserver startupPPObs); */
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs) = 0;

  /* void setMsgType (in long aMsgType); */
  NS_IMETHOD SetMsgType(PRInt32 aMsgType) = 0;

  /* attribute boolean doPrintPreview; */
  NS_IMETHOD GetDoPrintPreview(PRBool *aDoPrintPreview) = 0;
  NS_IMETHOD SetDoPrintPreview(PRBool aDoPrintPreview) = 0;

  /* readonly attribute nsIWebBrowserPrint webBrowserPrint; */
  NS_IMETHOD GetWebBrowserPrint(nsIWebBrowserPrint * *aWebBrowserPrint) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPRINTENGINE \
  NS_IMETHOD SetWindow(nsIDOMWindowInternal *ptr); \
  NS_IMETHOD SetParentWindow(nsIDOMWindowInternal *ptr); \
  NS_IMETHOD ShowWindow(PRBool aShow); \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback); \
  NS_IMETHOD SetPrintURICount(PRInt32 aCount); \
  NS_IMETHOD AddPrintURI(const PRUnichar *aURI); \
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS); \
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs); \
  NS_IMETHOD SetMsgType(PRInt32 aMsgType); \
  NS_IMETHOD GetDoPrintPreview(PRBool *aDoPrintPreview); \
  NS_IMETHOD SetDoPrintPreview(PRBool aDoPrintPreview); \
  NS_IMETHOD GetWebBrowserPrint(nsIWebBrowserPrint * *aWebBrowserPrint); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPRINTENGINE(_to) \
  NS_IMETHOD SetWindow(nsIDOMWindowInternal *ptr) { return _to SetWindow(ptr); } \
  NS_IMETHOD SetParentWindow(nsIDOMWindowInternal *ptr) { return _to SetParentWindow(ptr); } \
  NS_IMETHOD ShowWindow(PRBool aShow) { return _to ShowWindow(aShow); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback) { return _to SetStatusFeedback(feedback); } \
  NS_IMETHOD SetPrintURICount(PRInt32 aCount) { return _to SetPrintURICount(aCount); } \
  NS_IMETHOD AddPrintURI(const PRUnichar *aURI) { return _to AddPrintURI(aURI); } \
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS) { return _to StartPrintOperation(aPS); } \
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs) { return _to SetStartupPPObserver(startupPPObs); } \
  NS_IMETHOD SetMsgType(PRInt32 aMsgType) { return _to SetMsgType(aMsgType); } \
  NS_IMETHOD GetDoPrintPreview(PRBool *aDoPrintPreview) { return _to GetDoPrintPreview(aDoPrintPreview); } \
  NS_IMETHOD SetDoPrintPreview(PRBool aDoPrintPreview) { return _to SetDoPrintPreview(aDoPrintPreview); } \
  NS_IMETHOD GetWebBrowserPrint(nsIWebBrowserPrint * *aWebBrowserPrint) { return _to GetWebBrowserPrint(aWebBrowserPrint); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPRINTENGINE(_to) \
  NS_IMETHOD SetWindow(nsIDOMWindowInternal *ptr) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWindow(ptr); } \
  NS_IMETHOD SetParentWindow(nsIDOMWindowInternal *ptr) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetParentWindow(ptr); } \
  NS_IMETHOD ShowWindow(PRBool aShow) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowWindow(aShow); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStatusFeedback(feedback); } \
  NS_IMETHOD SetPrintURICount(PRInt32 aCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPrintURICount(aCount); } \
  NS_IMETHOD AddPrintURI(const PRUnichar *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddPrintURI(aURI); } \
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartPrintOperation(aPS); } \
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStartupPPObserver(startupPPObs); } \
  NS_IMETHOD SetMsgType(PRInt32 aMsgType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgType(aMsgType); } \
  NS_IMETHOD GetDoPrintPreview(PRBool *aDoPrintPreview) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDoPrintPreview(aDoPrintPreview); } \
  NS_IMETHOD SetDoPrintPreview(PRBool aDoPrintPreview) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDoPrintPreview(aDoPrintPreview); } \
  NS_IMETHOD GetWebBrowserPrint(nsIWebBrowserPrint * *aWebBrowserPrint) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWebBrowserPrint(aWebBrowserPrint); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgPrintEngine : public nsIMsgPrintEngine
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPRINTENGINE

  nsMsgPrintEngine();

private:
  ~nsMsgPrintEngine();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgPrintEngine, nsIMsgPrintEngine)

nsMsgPrintEngine::nsMsgPrintEngine()
{
  /* member initializers and constructor code */
}

nsMsgPrintEngine::~nsMsgPrintEngine()
{
  /* destructor code */
}

/* void setWindow (in nsIDOMWindowInternal ptr); */
NS_IMETHODIMP nsMsgPrintEngine::SetWindow(nsIDOMWindowInternal *ptr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setParentWindow (in nsIDOMWindowInternal ptr); */
NS_IMETHODIMP nsMsgPrintEngine::SetParentWindow(nsIDOMWindowInternal *ptr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void showWindow (in boolean aShow); */
NS_IMETHODIMP nsMsgPrintEngine::ShowWindow(PRBool aShow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStatusFeedback (in nsIMsgStatusFeedback feedback); */
NS_IMETHODIMP nsMsgPrintEngine::SetStatusFeedback(nsIMsgStatusFeedback *feedback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setPrintURICount (in PRInt32 aCount); */
NS_IMETHODIMP nsMsgPrintEngine::SetPrintURICount(PRInt32 aCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addPrintURI (in wstring aURI); */
NS_IMETHODIMP nsMsgPrintEngine::AddPrintURI(const PRUnichar *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void startPrintOperation (in nsIPrintSettings aPS); */
NS_IMETHODIMP nsMsgPrintEngine::StartPrintOperation(nsIPrintSettings *aPS)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStartupPPObserver (in nsIObserver startupPPObs); */
NS_IMETHODIMP nsMsgPrintEngine::SetStartupPPObserver(nsIObserver *startupPPObs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setMsgType (in long aMsgType); */
NS_IMETHODIMP nsMsgPrintEngine::SetMsgType(PRInt32 aMsgType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean doPrintPreview; */
NS_IMETHODIMP nsMsgPrintEngine::GetDoPrintPreview(PRBool *aDoPrintPreview)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgPrintEngine::SetDoPrintPreview(PRBool aDoPrintPreview)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIWebBrowserPrint webBrowserPrint; */
NS_IMETHODIMP nsMsgPrintEngine::GetWebBrowserPrint(nsIWebBrowserPrint * *aWebBrowserPrint)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgPrintEngine_h__ */
