/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIStatusBarBiffManager.idl
 */

#ifndef __gen_nsIStatusBarBiffManager_h__
#define __gen_nsIStatusBarBiffManager_h__


#ifndef __gen_nsIMsgFolder_h__
#include "nsIMsgFolder.h"
#endif

#ifndef __gen_nsIFolderListener_h__
#include "nsIFolderListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIStatusBarBiffManager */
#define NS_ISTATUSBARBIFFMANAGER_IID_STR "a767c5d1-5142-41a2-8873-71df09b4ce89"

#define NS_ISTATUSBARBIFFMANAGER_IID \
  {0xa767c5d1, 0x5142, 0x41a2, \
    { 0x88, 0x73, 0x71, 0xdf, 0x09, 0xb4, 0xce, 0x89 }}

class NS_NO_VTABLE nsIStatusBarBiffManager : public nsIFolderListener {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISTATUSBARBIFFMANAGER_IID)

  /* readonly attribute nsMsgBiffState biffState; */
  NS_IMETHOD GetBiffState(nsMsgBiffState *aBiffState) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISTATUSBARBIFFMANAGER \
  NS_IMETHOD GetBiffState(nsMsgBiffState *aBiffState); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISTATUSBARBIFFMANAGER(_to) \
  NS_IMETHOD GetBiffState(nsMsgBiffState *aBiffState) { return _to GetBiffState(aBiffState); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISTATUSBARBIFFMANAGER(_to) \
  NS_IMETHOD GetBiffState(nsMsgBiffState *aBiffState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBiffState(aBiffState); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsStatusBarBiffManager : public nsIStatusBarBiffManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISTATUSBARBIFFMANAGER

  nsStatusBarBiffManager();

private:
  ~nsStatusBarBiffManager();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsStatusBarBiffManager, nsIStatusBarBiffManager)

nsStatusBarBiffManager::nsStatusBarBiffManager()
{
  /* member initializers and constructor code */
}

nsStatusBarBiffManager::~nsStatusBarBiffManager()
{
  /* destructor code */
}

/* readonly attribute nsMsgBiffState biffState; */
NS_IMETHODIMP nsStatusBarBiffManager::GetBiffState(nsMsgBiffState *aBiffState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIStatusBarBiffManager_h__ */
