/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgLocalMailFolder.idl
 */

#ifndef __gen_nsIMsgLocalMailFolder_h__
#define __gen_nsIMsgLocalMailFolder_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsISupportsArray_h__
#include "nsISupportsArray.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIMsgCopyServiceListener; /* forward declaration */

/* flags for markMsgsOnPop3Server */
#define POP3_NONE	0
#define POP3_DELETE	1
#define POP3_FETCH_BODY	2
#define POP3_FORCE_DEL	3
struct nsLocalFolderScanState;

/* starting interface:    nsIMsgLocalMailFolder */
#define NS_IMSGLOCALMAILFOLDER_IID_STR "260398bd-9152-4b10-af4e-3126dcd37837"

#define NS_IMSGLOCALMAILFOLDER_IID \
  {0x260398bd, 0x9152, 0x4b10, \
    { 0xaf, 0x4e, 0x31, 0x26, 0xdc, 0xd3, 0x78, 0x37 }}

class NS_NO_VTABLE nsIMsgLocalMailFolder : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGLOCALMAILFOLDER_IID)

  /**
   * set the default flags on the subfolders of this folder, such as
   * Drafts, Templates, etc
   * you should bitwise OR all the flags all mailboxes you want to flag,
   * this function will be smart and find the right names.
   * like MSG_FOLDER_FLAG_INBOX | MSG_FOLDER_FLAG_DRAFTS | etc
   */
  /* void setFlagsOnDefaultMailboxes (in unsigned long flags); */
  NS_IMETHOD SetFlagsOnDefaultMailboxes(PRUint32 flags) = 0;

  /* nsIMsgDatabase getDatabaseWOReparse (); */
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase **_retval) = 0;

  /* nsIMsgDatabase getDatabaseWithReparse (in nsIUrlListener aReparseUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase **_retval) = 0;

  /* void parseFolder (in nsIMsgWindow aMsgWindow, in nsIUrlListener listener); */
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener) = 0;

  /* void copyFolderLocal (in nsIMsgFolder srcFolder, in boolean isMove, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, PRBool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) = 0;

  /* void copyAllSubFolders (in nsIMsgFolder srcFolder, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) = 0;

  /* void onCopyCompleted (in nsISupports aSrcSupport, in boolean aMoveCopySucceeded); */
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, PRBool aMoveCopySucceeded) = 0;

  /* attribute boolean checkForNewMessagesAfterParsing; */
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(PRBool *aCheckForNewMessagesAfterParsing) = 0;
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(PRBool aCheckForNewMessagesAfterParsing) = 0;

  /* [noscript] void markMsgsOnPop3Server (in nsISupportsArray aMessages, in PRInt32 aMark); */
  NS_IMETHOD MarkMsgsOnPop3Server(nsISupportsArray *aMessages, PRInt32 aMark) = 0;

  /* void refreshSizeOnDisk (); */
  NS_IMETHOD RefreshSizeOnDisk(void) = 0;

  /* void addMessage (in string aMessage); */
  NS_IMETHOD AddMessage(const char *aMessage) = 0;

  /**
   * functions for updating the UI while running DownloadMessagesForOffline:
   * delete the old message before adding its newly downloaded body, and
   * select the new message after it has replaced the old one
   */
  /* void deleteDownloadMsg (in nsIMsgDBHdr aMsgHdr, out boolean aDoSelect); */
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, PRBool *aDoSelect) = 0;

  /* void selectDownloadMsg (); */
  NS_IMETHOD SelectDownloadMsg(void) = 0;

  /* void notifyDelete (); */
  NS_IMETHOD NotifyDelete(void) = 0;

  /**
   * functions for grubbing thru a folder to find the Uidl for a
   * given msgDBHdr
   */
  /* [noscript] void getFolderScanState (in nsLocalFolderScanState aState); */
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState * aState) = 0;

  /* [noscript] void getUidlFromFolder (in nsLocalFolderScanState aState, in nsIMsgDBHdr aMsgHdr); */
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState * aState, nsIMsgDBHdr *aMsgHdr) = 0;

  /* boolean warnIfLocalFileTooBig (in nsIMsgWindow aWindow); */
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGLOCALMAILFOLDER \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(PRUint32 flags); \
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase **_retval); \
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase **_retval); \
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener); \
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, PRBool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener); \
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener); \
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, PRBool aMoveCopySucceeded); \
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(PRBool *aCheckForNewMessagesAfterParsing); \
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(PRBool aCheckForNewMessagesAfterParsing); \
  NS_IMETHOD MarkMsgsOnPop3Server(nsISupportsArray *aMessages, PRInt32 aMark); \
  NS_IMETHOD RefreshSizeOnDisk(void); \
  NS_IMETHOD AddMessage(const char *aMessage); \
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, PRBool *aDoSelect); \
  NS_IMETHOD SelectDownloadMsg(void); \
  NS_IMETHOD NotifyDelete(void); \
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState * aState); \
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState * aState, nsIMsgDBHdr *aMsgHdr); \
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGLOCALMAILFOLDER(_to) \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(PRUint32 flags) { return _to SetFlagsOnDefaultMailboxes(flags); } \
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase **_retval) { return _to GetDatabaseWOReparse(_retval); } \
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase **_retval) { return _to GetDatabaseWithReparse(aReparseUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener) { return _to ParseFolder(aMsgWindow, listener); } \
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, PRBool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return _to CopyFolderLocal(srcFolder, isMove, msgWindow, listener); } \
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return _to CopyAllSubFolders(srcFolder, msgWindow, listener); } \
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, PRBool aMoveCopySucceeded) { return _to OnCopyCompleted(aSrcSupport, aMoveCopySucceeded); } \
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(PRBool *aCheckForNewMessagesAfterParsing) { return _to GetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(PRBool aCheckForNewMessagesAfterParsing) { return _to SetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD MarkMsgsOnPop3Server(nsISupportsArray *aMessages, PRInt32 aMark) { return _to MarkMsgsOnPop3Server(aMessages, aMark); } \
  NS_IMETHOD RefreshSizeOnDisk(void) { return _to RefreshSizeOnDisk(); } \
  NS_IMETHOD AddMessage(const char *aMessage) { return _to AddMessage(aMessage); } \
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, PRBool *aDoSelect) { return _to DeleteDownloadMsg(aMsgHdr, aDoSelect); } \
  NS_IMETHOD SelectDownloadMsg(void) { return _to SelectDownloadMsg(); } \
  NS_IMETHOD NotifyDelete(void) { return _to NotifyDelete(); } \
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState * aState) { return _to GetFolderScanState(aState); } \
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState * aState, nsIMsgDBHdr *aMsgHdr) { return _to GetUidlFromFolder(aState, aMsgHdr); } \
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, PRBool *_retval) { return _to WarnIfLocalFileTooBig(aWindow, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGLOCALMAILFOLDER(_to) \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(PRUint32 flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFlagsOnDefaultMailboxes(flags); } \
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDatabaseWOReparse(_retval); } \
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDatabaseWithReparse(aReparseUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->ParseFolder(aMsgWindow, listener); } \
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, PRBool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->CopyFolderLocal(srcFolder, isMove, msgWindow, listener); } \
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->CopyAllSubFolders(srcFolder, msgWindow, listener); } \
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, PRBool aMoveCopySucceeded) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnCopyCompleted(aSrcSupport, aMoveCopySucceeded); } \
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(PRBool *aCheckForNewMessagesAfterParsing) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(PRBool aCheckForNewMessagesAfterParsing) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD MarkMsgsOnPop3Server(nsISupportsArray *aMessages, PRInt32 aMark) { return !_to ? NS_ERROR_NULL_POINTER : _to->MarkMsgsOnPop3Server(aMessages, aMark); } \
  NS_IMETHOD RefreshSizeOnDisk(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->RefreshSizeOnDisk(); } \
  NS_IMETHOD AddMessage(const char *aMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMessage(aMessage); } \
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, PRBool *aDoSelect) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteDownloadMsg(aMsgHdr, aDoSelect); } \
  NS_IMETHOD SelectDownloadMsg(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->SelectDownloadMsg(); } \
  NS_IMETHOD NotifyDelete(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyDelete(); } \
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState * aState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderScanState(aState); } \
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState * aState, nsIMsgDBHdr *aMsgHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUidlFromFolder(aState, aMsgHdr); } \
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->WarnIfLocalFileTooBig(aWindow, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgLocalMailFolder : public nsIMsgLocalMailFolder
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGLOCALMAILFOLDER

  nsMsgLocalMailFolder();

private:
  ~nsMsgLocalMailFolder();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgLocalMailFolder, nsIMsgLocalMailFolder)

nsMsgLocalMailFolder::nsMsgLocalMailFolder()
{
  /* member initializers and constructor code */
}

nsMsgLocalMailFolder::~nsMsgLocalMailFolder()
{
  /* destructor code */
}

/* void setFlagsOnDefaultMailboxes (in unsigned long flags); */
NS_IMETHODIMP nsMsgLocalMailFolder::SetFlagsOnDefaultMailboxes(PRUint32 flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgDatabase getDatabaseWOReparse (); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetDatabaseWOReparse(nsIMsgDatabase **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgDatabase getDatabaseWithReparse (in nsIUrlListener aReparseUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void parseFolder (in nsIMsgWindow aMsgWindow, in nsIUrlListener listener); */
NS_IMETHODIMP nsMsgLocalMailFolder::ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void copyFolderLocal (in nsIMsgFolder srcFolder, in boolean isMove, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
NS_IMETHODIMP nsMsgLocalMailFolder::CopyFolderLocal(nsIMsgFolder *srcFolder, PRBool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void copyAllSubFolders (in nsIMsgFolder srcFolder, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
NS_IMETHODIMP nsMsgLocalMailFolder::CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onCopyCompleted (in nsISupports aSrcSupport, in boolean aMoveCopySucceeded); */
NS_IMETHODIMP nsMsgLocalMailFolder::OnCopyCompleted(nsISupports *aSrcSupport, PRBool aMoveCopySucceeded)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean checkForNewMessagesAfterParsing; */
NS_IMETHODIMP nsMsgLocalMailFolder::GetCheckForNewMessagesAfterParsing(PRBool *aCheckForNewMessagesAfterParsing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgLocalMailFolder::SetCheckForNewMessagesAfterParsing(PRBool aCheckForNewMessagesAfterParsing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void markMsgsOnPop3Server (in nsISupportsArray aMessages, in PRInt32 aMark); */
NS_IMETHODIMP nsMsgLocalMailFolder::MarkMsgsOnPop3Server(nsISupportsArray *aMessages, PRInt32 aMark)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void refreshSizeOnDisk (); */
NS_IMETHODIMP nsMsgLocalMailFolder::RefreshSizeOnDisk()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addMessage (in string aMessage); */
NS_IMETHODIMP nsMsgLocalMailFolder::AddMessage(const char *aMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteDownloadMsg (in nsIMsgDBHdr aMsgHdr, out boolean aDoSelect); */
NS_IMETHODIMP nsMsgLocalMailFolder::DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, PRBool *aDoSelect)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void selectDownloadMsg (); */
NS_IMETHODIMP nsMsgLocalMailFolder::SelectDownloadMsg()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyDelete (); */
NS_IMETHODIMP nsMsgLocalMailFolder::NotifyDelete()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void getFolderScanState (in nsLocalFolderScanState aState); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetFolderScanState(nsLocalFolderScanState * aState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void getUidlFromFolder (in nsLocalFolderScanState aState, in nsIMsgDBHdr aMsgHdr); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetUidlFromFolder(nsLocalFolderScanState * aState, nsIMsgDBHdr *aMsgHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean warnIfLocalFileTooBig (in nsIMsgWindow aWindow); */
NS_IMETHODIMP nsMsgLocalMailFolder::WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgLocalMailFolder_h__ */
