/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Mozilla SVG project.
 *
 * The Initial Developer of the Original Code is
 * Crocodile Clips Ltd.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Alex Fritze <alex@croczilla.com> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


#include "nsISVGGlyphMetricsSource.idl"

interface nsISVGRendererGlyphMetrics;

/**
 * \addtogroup rendering_backend_interfaces Rendering Backend Interfaces
 * @{
 */

/**
 * Abstracts a description of a 'composite glyph' (character string
 * with associated font and styling information) in the SVG rendering
 * backend for use by a rendering engine's nsISVGRendererGlyphGeometry
 * objects. In addition to the attributes of the
 * nsISVGGlyphMetricsSource interface, this interface contains
 * absolute positioning and other information, such as e.g. individual
 * character highlighting, which doesn't affect the actual metrics of
 * the glyph. The metrics of the glyph, as given by the rendering
 * engine-native object implementing nsISVGRendererGlyphMetrics are
 * also provided as an attribute.
 *
 * An engine-native glyph geometry object will be informed of changes
 * in its associated composite glyph with a call to its
 * nsISVGRendererGlyphMetrics::update() method with an OR-ed
 * combination of the UPDATEMASK_* constants defined in this interface
 * (and its base-interface).
 *
 * @nosubgrouping
 */
[uuid(b36065f1-c52b-4eda-b9ad-e483cf1a63bf)]
interface nsISVGGlyphGeometrySource : nsISVGGlyphMetricsSource
{
  /**
   * @name Glyph metrics
   * @{
   */
  readonly attribute nsISVGRendererGlyphMetrics metrics;
  const unsigned long UPDATEMASK_METRICS       = 0x00040000;
  /** @} */

  /**
   * @name Glyph start position
   * @{
   */
  readonly attribute float x; // start position of glyph *before* applying CanvasTM
  const unsigned long UPDATEMASK_X             = 0x00080000;
  readonly attribute float y;
  const unsigned long UPDATEMASK_Y             = 0x00100000;
  /** @} */

  /**
   * @name Partial highlighting for selection feedback
   * @{
   */
  readonly attribute boolean hasHighlight;
  const unsigned long UPDATEMASK_HAS_HIGHLIGHT = 0x00200000;
  [noscript] void getHighlight(out unsigned long charnum, out unsigned long nchars,
                               out nscolor foreground, out nscolor background);
  const unsigned long UPDATEMASK_HIGHLIGHT     = 0x00400000;
  /** @} */
};

/** @} */
