/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsISmtpService.idl
 */

#ifndef __gen_nsISmtpService_h__
#define __gen_nsISmtpService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsISmtpServer; /* forward declaration */

class nsIURI; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsISupportsArray; /* forward declaration */

class nsIMsgIdentity; /* forward declaration */

class nsIInterfaceRequestor; /* forward declaration */

class nsIFileSpec; /* forward declaration */

class nsIMsgStatusFeedback; /* forward declaration */

class nsIRequest; /* forward declaration */


/* starting interface:    nsISmtpService */
#define NS_ISMTPSERVICE_IID_STR "fbaf0f10-ca9b-11d2-8063-006008128c4e"

#define NS_ISMTPSERVICE_IID \
  {0xfbaf0f10, 0xca9b, 0x11d2, \
    { 0x80, 0x63, 0x00, 0x60, 0x08, 0x12, 0x8c, 0x4e }}

class NS_NO_VTABLE nsISmtpService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISMTPSERVICE_IID)

  /* void SendMailMessage (in nsIFileSpec aFilePath, in string aRecipients, in nsIMsgIdentity aSenderIdentity, in string aPassword, in nsIUrlListener aUrlListener, in nsIMsgStatusFeedback aStatusListener, in nsIInterfaceRequestor aNotificationCallbacks, out nsIURI aURL, out nsIRequest aRequest); */
  NS_IMETHOD SendMailMessage(nsIFileSpec *aFilePath, const char *aRecipients, nsIMsgIdentity *aSenderIdentity, const char *aPassword, nsIUrlListener *aUrlListener, nsIMsgStatusFeedback *aStatusListener, nsIInterfaceRequestor *aNotificationCallbacks, nsIURI **aURL, nsIRequest **aRequest) = 0;

  /**
   * Return the SMTP server that is associated with an identity.
   */
  /* void GetSmtpServerByIdentity (in nsIMsgIdentity aSenderIdentity, out nsISmtpServer aServer); */
  NS_IMETHOD GetSmtpServerByIdentity(nsIMsgIdentity *aSenderIdentity, nsISmtpServer **aServer) = 0;

  /**
   * A copy of the array of SMTP servers, as stored in the preferences
   */
  /* readonly attribute nsISupportsArray smtpServers; */
  NS_IMETHOD GetSmtpServers(nsISupportsArray * *aSmtpServers) = 0;

  /**
   * The default server, across sessions of the app
   * (eventually there will be a session default which does not
   * persist past shutdown)
   */
  /* attribute nsISmtpServer defaultServer; */
  NS_IMETHOD GetDefaultServer(nsISmtpServer * *aDefaultServer) = 0;
  NS_IMETHOD SetDefaultServer(nsISmtpServer * aDefaultServer) = 0;

  /**
   * The "session default" server - this is never saved, and only used
   * for the current session. Always falls back to the default server
   * unless explicitly set.
   */
  /* attribute nsISmtpServer sessionDefaultServer; */
  NS_IMETHOD GetSessionDefaultServer(nsISmtpServer * *aSessionDefaultServer) = 0;
  NS_IMETHOD SetSessionDefaultServer(nsISmtpServer * aSessionDefaultServer) = 0;

  /**
   * create a new SMTP server.
   * Use this instead of createInstance(), so that the SMTP Service can
   * be aware of this server
   */
  /* nsISmtpServer createSmtpServer (); */
  NS_IMETHOD CreateSmtpServer(nsISmtpServer **_retval) = 0;

  /**
   * find the server with the given hostname.
   * @param hostname the hostname of the server
   * @returns null if no server is found
   */
  /* nsISmtpServer findServer (in string username, in string hostname); */
  NS_IMETHOD FindServer(const char *username, const char *hostname, nsISmtpServer **_retval) = 0;

  /**
   * look up the server with the given key
   * if the server does not exist, create it and add it to our list
   */
  /* nsISmtpServer getServerByKey (in string key); */
  NS_IMETHOD GetServerByKey(const char *key, nsISmtpServer **_retval) = 0;

  /**
   * delete the given server from the server list.
   * does nothing if the server does not exist
   * @param server the server to delete. Use findServer() if you only know
   *   the hostname
   */
  /* void deleteSmtpServer (in nsISmtpServer server); */
  NS_IMETHOD DeleteSmtpServer(nsISmtpServer *server) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISMTPSERVICE \
  NS_IMETHOD SendMailMessage(nsIFileSpec *aFilePath, const char *aRecipients, nsIMsgIdentity *aSenderIdentity, const char *aPassword, nsIUrlListener *aUrlListener, nsIMsgStatusFeedback *aStatusListener, nsIInterfaceRequestor *aNotificationCallbacks, nsIURI **aURL, nsIRequest **aRequest); \
  NS_IMETHOD GetSmtpServerByIdentity(nsIMsgIdentity *aSenderIdentity, nsISmtpServer **aServer); \
  NS_IMETHOD GetSmtpServers(nsISupportsArray * *aSmtpServers); \
  NS_IMETHOD GetDefaultServer(nsISmtpServer * *aDefaultServer); \
  NS_IMETHOD SetDefaultServer(nsISmtpServer * aDefaultServer); \
  NS_IMETHOD GetSessionDefaultServer(nsISmtpServer * *aSessionDefaultServer); \
  NS_IMETHOD SetSessionDefaultServer(nsISmtpServer * aSessionDefaultServer); \
  NS_IMETHOD CreateSmtpServer(nsISmtpServer **_retval); \
  NS_IMETHOD FindServer(const char *username, const char *hostname, nsISmtpServer **_retval); \
  NS_IMETHOD GetServerByKey(const char *key, nsISmtpServer **_retval); \
  NS_IMETHOD DeleteSmtpServer(nsISmtpServer *server); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISMTPSERVICE(_to) \
  NS_IMETHOD SendMailMessage(nsIFileSpec *aFilePath, const char *aRecipients, nsIMsgIdentity *aSenderIdentity, const char *aPassword, nsIUrlListener *aUrlListener, nsIMsgStatusFeedback *aStatusListener, nsIInterfaceRequestor *aNotificationCallbacks, nsIURI **aURL, nsIRequest **aRequest) { return _to SendMailMessage(aFilePath, aRecipients, aSenderIdentity, aPassword, aUrlListener, aStatusListener, aNotificationCallbacks, aURL, aRequest); } \
  NS_IMETHOD GetSmtpServerByIdentity(nsIMsgIdentity *aSenderIdentity, nsISmtpServer **aServer) { return _to GetSmtpServerByIdentity(aSenderIdentity, aServer); } \
  NS_IMETHOD GetSmtpServers(nsISupportsArray * *aSmtpServers) { return _to GetSmtpServers(aSmtpServers); } \
  NS_IMETHOD GetDefaultServer(nsISmtpServer * *aDefaultServer) { return _to GetDefaultServer(aDefaultServer); } \
  NS_IMETHOD SetDefaultServer(nsISmtpServer * aDefaultServer) { return _to SetDefaultServer(aDefaultServer); } \
  NS_IMETHOD GetSessionDefaultServer(nsISmtpServer * *aSessionDefaultServer) { return _to GetSessionDefaultServer(aSessionDefaultServer); } \
  NS_IMETHOD SetSessionDefaultServer(nsISmtpServer * aSessionDefaultServer) { return _to SetSessionDefaultServer(aSessionDefaultServer); } \
  NS_IMETHOD CreateSmtpServer(nsISmtpServer **_retval) { return _to CreateSmtpServer(_retval); } \
  NS_IMETHOD FindServer(const char *username, const char *hostname, nsISmtpServer **_retval) { return _to FindServer(username, hostname, _retval); } \
  NS_IMETHOD GetServerByKey(const char *key, nsISmtpServer **_retval) { return _to GetServerByKey(key, _retval); } \
  NS_IMETHOD DeleteSmtpServer(nsISmtpServer *server) { return _to DeleteSmtpServer(server); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISMTPSERVICE(_to) \
  NS_IMETHOD SendMailMessage(nsIFileSpec *aFilePath, const char *aRecipients, nsIMsgIdentity *aSenderIdentity, const char *aPassword, nsIUrlListener *aUrlListener, nsIMsgStatusFeedback *aStatusListener, nsIInterfaceRequestor *aNotificationCallbacks, nsIURI **aURL, nsIRequest **aRequest) { return !_to ? NS_ERROR_NULL_POINTER : _to->SendMailMessage(aFilePath, aRecipients, aSenderIdentity, aPassword, aUrlListener, aStatusListener, aNotificationCallbacks, aURL, aRequest); } \
  NS_IMETHOD GetSmtpServerByIdentity(nsIMsgIdentity *aSenderIdentity, nsISmtpServer **aServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSmtpServerByIdentity(aSenderIdentity, aServer); } \
  NS_IMETHOD GetSmtpServers(nsISupportsArray * *aSmtpServers) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSmtpServers(aSmtpServers); } \
  NS_IMETHOD GetDefaultServer(nsISmtpServer * *aDefaultServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultServer(aDefaultServer); } \
  NS_IMETHOD SetDefaultServer(nsISmtpServer * aDefaultServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDefaultServer(aDefaultServer); } \
  NS_IMETHOD GetSessionDefaultServer(nsISmtpServer * *aSessionDefaultServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSessionDefaultServer(aSessionDefaultServer); } \
  NS_IMETHOD SetSessionDefaultServer(nsISmtpServer * aSessionDefaultServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSessionDefaultServer(aSessionDefaultServer); } \
  NS_IMETHOD CreateSmtpServer(nsISmtpServer **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateSmtpServer(_retval); } \
  NS_IMETHOD FindServer(const char *username, const char *hostname, nsISmtpServer **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindServer(username, hostname, _retval); } \
  NS_IMETHOD GetServerByKey(const char *key, nsISmtpServer **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetServerByKey(key, _retval); } \
  NS_IMETHOD DeleteSmtpServer(nsISmtpServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteSmtpServer(server); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSmtpService : public nsISmtpService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISMTPSERVICE

  nsSmtpService();

private:
  ~nsSmtpService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSmtpService, nsISmtpService)

nsSmtpService::nsSmtpService()
{
  /* member initializers and constructor code */
}

nsSmtpService::~nsSmtpService()
{
  /* destructor code */
}

/* void SendMailMessage (in nsIFileSpec aFilePath, in string aRecipients, in nsIMsgIdentity aSenderIdentity, in string aPassword, in nsIUrlListener aUrlListener, in nsIMsgStatusFeedback aStatusListener, in nsIInterfaceRequestor aNotificationCallbacks, out nsIURI aURL, out nsIRequest aRequest); */
NS_IMETHODIMP nsSmtpService::SendMailMessage(nsIFileSpec *aFilePath, const char *aRecipients, nsIMsgIdentity *aSenderIdentity, const char *aPassword, nsIUrlListener *aUrlListener, nsIMsgStatusFeedback *aStatusListener, nsIInterfaceRequestor *aNotificationCallbacks, nsIURI **aURL, nsIRequest **aRequest)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void GetSmtpServerByIdentity (in nsIMsgIdentity aSenderIdentity, out nsISmtpServer aServer); */
NS_IMETHODIMP nsSmtpService::GetSmtpServerByIdentity(nsIMsgIdentity *aSenderIdentity, nsISmtpServer **aServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsISupportsArray smtpServers; */
NS_IMETHODIMP nsSmtpService::GetSmtpServers(nsISupportsArray * *aSmtpServers)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsISmtpServer defaultServer; */
NS_IMETHODIMP nsSmtpService::GetDefaultServer(nsISmtpServer * *aDefaultServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpService::SetDefaultServer(nsISmtpServer * aDefaultServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsISmtpServer sessionDefaultServer; */
NS_IMETHODIMP nsSmtpService::GetSessionDefaultServer(nsISmtpServer * *aSessionDefaultServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpService::SetSessionDefaultServer(nsISmtpServer * aSessionDefaultServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISmtpServer createSmtpServer (); */
NS_IMETHODIMP nsSmtpService::CreateSmtpServer(nsISmtpServer **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISmtpServer findServer (in string username, in string hostname); */
NS_IMETHODIMP nsSmtpService::FindServer(const char *username, const char *hostname, nsISmtpServer **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISmtpServer getServerByKey (in string key); */
NS_IMETHODIMP nsSmtpService::GetServerByKey(const char *key, nsISmtpServer **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteSmtpServer (in nsISmtpServer server); */
NS_IMETHODIMP nsSmtpService::DeleteSmtpServer(nsISmtpServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISmtpService_h__ */
