/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsINNTPNewsgroupList.idl
 */

#ifndef __gen_nsINNTPNewsgroupList_h__
#define __gen_nsINNTPNewsgroupList_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgNewsFolder; /* forward declaration */

class nsINntpUrl; /* forward declaration */

class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsINNTPNewsgroupList */
#define NS_INNTPNEWSGROUPLIST_IID_STR "e628ed19-9452-11d2-b7ea-00805f05ffa5"

#define NS_INNTPNEWSGROUPLIST_IID \
  {0xe628ed19, 0x9452, 0x11d2, \
    { 0xb7, 0xea, 0x00, 0x80, 0x5f, 0x05, 0xff, 0xa5 }}

class NS_NO_VTABLE nsINNTPNewsgroupList : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_INNTPNEWSGROUPLIST_IID)

  /* void initialize (in nsINntpUrl runningURL, in nsIMsgNewsFolder newsFolder); */
  NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder) = 0;

  /* long getRangeOfArtsToDownload (in nsIMsgWindow aMsgWindow, in long first_message, in long last_message, in long maxextra, out long real_first_message, out long real_last_message); */
  NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message, PRInt32 *real_last_message, PRInt32 *_retval) = 0;

  /* void addToKnownArticles (in long first_message, in long last_message); */
  NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message) = 0;

  /* void initXOVER (in long first_message, in long last_message); */
  NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message) = 0;

  /* void processXOVERLINE (in string line, out unsigned long status); */
  NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status) = 0;

  /* void processNonXOVER (in string line); */
  NS_IMETHOD ProcessNonXOVER(const char *line) = 0;

  /* void resetXOVER (); */
  NS_IMETHOD ResetXOVER(void) = 0;

  /* void finishXOVERLINE (in long status, out long newstatus); */
  NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus) = 0;

  /* void clearXOVERState (); */
  NS_IMETHOD ClearXOVERState(void) = 0;

  /* attribute boolean getOldMessages; */
  NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages) = 0;
  NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINNTPNEWSGROUPLIST \
  NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder); \
  NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message, PRInt32 *real_last_message, PRInt32 *_retval); \
  NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message); \
  NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message); \
  NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status); \
  NS_IMETHOD ProcessNonXOVER(const char *line); \
  NS_IMETHOD ResetXOVER(void); \
  NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus); \
  NS_IMETHOD ClearXOVERState(void); \
  NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages); \
  NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINNTPNEWSGROUPLIST(_to) \
  NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder) { return _to Initialize(runningURL, newsFolder); } \
  NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message, PRInt32 *real_last_message, PRInt32 *_retval) { return _to GetRangeOfArtsToDownload(aMsgWindow, first_message, last_message, maxextra, real_first_message, real_last_message, _retval); } \
  NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message) { return _to AddToKnownArticles(first_message, last_message); } \
  NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message) { return _to InitXOVER(first_message, last_message); } \
  NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status) { return _to ProcessXOVERLINE(line, status); } \
  NS_IMETHOD ProcessNonXOVER(const char *line) { return _to ProcessNonXOVER(line); } \
  NS_IMETHOD ResetXOVER(void) { return _to ResetXOVER(); } \
  NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus) { return _to FinishXOVERLINE(status, newstatus); } \
  NS_IMETHOD ClearXOVERState(void) { return _to ClearXOVERState(); } \
  NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages) { return _to GetGetOldMessages(aGetOldMessages); } \
  NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages) { return _to SetGetOldMessages(aGetOldMessages); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINNTPNEWSGROUPLIST(_to) \
  NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initialize(runningURL, newsFolder); } \
  NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message, PRInt32 *real_last_message, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRangeOfArtsToDownload(aMsgWindow, first_message, last_message, maxextra, real_first_message, real_last_message, _retval); } \
  NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddToKnownArticles(first_message, last_message); } \
  NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitXOVER(first_message, last_message); } \
  NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status) { return !_to ? NS_ERROR_NULL_POINTER : _to->ProcessXOVERLINE(line, status); } \
  NS_IMETHOD ProcessNonXOVER(const char *line) { return !_to ? NS_ERROR_NULL_POINTER : _to->ProcessNonXOVER(line); } \
  NS_IMETHOD ResetXOVER(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ResetXOVER(); } \
  NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus) { return !_to ? NS_ERROR_NULL_POINTER : _to->FinishXOVERLINE(status, newstatus); } \
  NS_IMETHOD ClearXOVERState(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearXOVERState(); } \
  NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetGetOldMessages(aGetOldMessages); } \
  NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetGetOldMessages(aGetOldMessages); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNNTPNewsgroupList : public nsINNTPNewsgroupList
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINNTPNEWSGROUPLIST

  nsNNTPNewsgroupList();

private:
  ~nsNNTPNewsgroupList();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNNTPNewsgroupList, nsINNTPNewsgroupList)

nsNNTPNewsgroupList::nsNNTPNewsgroupList()
{
  /* member initializers and constructor code */
}

nsNNTPNewsgroupList::~nsNNTPNewsgroupList()
{
  /* destructor code */
}

/* void initialize (in nsINntpUrl runningURL, in nsIMsgNewsFolder newsFolder); */
NS_IMETHODIMP nsNNTPNewsgroupList::Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getRangeOfArtsToDownload (in nsIMsgWindow aMsgWindow, in long first_message, in long last_message, in long maxextra, out long real_first_message, out long real_last_message); */
NS_IMETHODIMP nsNNTPNewsgroupList::GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message, PRInt32 *real_last_message, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addToKnownArticles (in long first_message, in long last_message); */
NS_IMETHODIMP nsNNTPNewsgroupList::AddToKnownArticles(PRInt32 first_message, PRInt32 last_message)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void initXOVER (in long first_message, in long last_message); */
NS_IMETHODIMP nsNNTPNewsgroupList::InitXOVER(PRInt32 first_message, PRInt32 last_message)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void processXOVERLINE (in string line, out unsigned long status); */
NS_IMETHODIMP nsNNTPNewsgroupList::ProcessXOVERLINE(const char *line, PRUint32 *status)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void processNonXOVER (in string line); */
NS_IMETHODIMP nsNNTPNewsgroupList::ProcessNonXOVER(const char *line)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void resetXOVER (); */
NS_IMETHODIMP nsNNTPNewsgroupList::ResetXOVER()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void finishXOVERLINE (in long status, out long newstatus); */
NS_IMETHODIMP nsNNTPNewsgroupList::FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearXOVERState (); */
NS_IMETHODIMP nsNNTPNewsgroupList::ClearXOVERState()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean getOldMessages; */
NS_IMETHODIMP nsNNTPNewsgroupList::GetGetOldMessages(PRBool *aGetOldMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupList::SetGetOldMessages(PRBool aGetOldMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINNTPNewsgroupList_h__ */
