/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "MailNewsTypes2.idl"

interface nsIMsgWindow;
interface nsIMsgMailNewsUrl;
interface nsIImapProtocol;
interface nsIImapUrl;

[scriptable, uuid(f61940a5-71d7-455a-8383-940d0b6a964b)]
interface nsIImapServerSink : nsISupports {
  /* returns true if it's a new mailbox */
  boolean possibleImapMailbox(in string folderPath, in wchar hierarchyDelim, in long boxFlags);
  boolean folderNeedsACLInitialized(in string folderPath);
  void addFolderRights(in string folderPath, in string userName, in string rights);
  void refreshFolderRights(in string folderPath);
  void discoveryDone();
  void onlineFolderDelete(in string aFolderName);
  void onlineFolderCreateFailed(in string aFolderName);
  void onlineFolderRename(in nsIMsgWindow msgWindow, in string oldName, in string newName);
  void folderIsNoSelect(in string aFolderName, out boolean aResult);
  void setFolderAdminURL(in string aFolderName, in string adminUrl);
  boolean folderVerifiedOnline(in string aFolderName);

  void setCapability(in unsigned long capability);
  void loadNextQueuedUrl(in nsIImapProtocol aProtocol, out boolean urlRun);
  void retryUrl(in nsIImapUrl aImapUrl);
  // if previous url failed, this gives server chance to abort urls with same mock channel
  void abortQueuedUrls(); 
  void getImapStringByID(in long aMsgId, out wstring aString);
  void formatStringWithHostNameByID(in long aMsgId, out wstring aString);
  void fEAlert(in wstring aString, in nsIMsgWindow aMsgWindow);
  void fEAlertFromServer(in string aString, in nsIMsgWindow aMsgWindow);
  void commitNamespaces();
  void promptForPassword(out string aString, in nsIMsgWindow aMsgWindow);
  attribute boolean userAuthenticated;
  void setMailServerUrls(in string manageMailAccount, in string manageLists, in string manageFilters);
  
  /* this is a bogus method on this interface but i need it until misc. sink is scriptable.. */
  void RemoveChannelFromUrl(in nsIMsgMailNewsUrl aUrl, in unsigned long statusCode);
  readonly attribute string arbitraryHeaders;
  void forgetPassword();

  readonly attribute boolean showAttachmentsInline;
  string cramMD5Hash(in string decodedChallenge, in string key);

};

