/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsPIAccessible.idl
 */

#ifndef __gen_nsPIAccessible_h__
#define __gen_nsPIAccessible_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAccessible; /* forward declaration */


/* starting interface:    nsPIAccessible */
#define NS_PIACCESSIBLE_IID_STR "52f1be88-84f7-4f7f-b31c-062afe7df15d"

#define NS_PIACCESSIBLE_IID \
  {0x52f1be88, 0x84f7, 0x4f7f, \
    { 0xb3, 0x1c, 0x06, 0x2a, 0xfe, 0x7d, 0xf1, 0x5d }}

class NS_NO_VTABLE nsPIAccessible : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_PIACCESSIBLE_IID)

  /* [noscript] void setParent (in nsIAccessible aAccParent); */
  NS_IMETHOD SetParent(nsIAccessible *aAccParent) = 0;

  /* [noscript] void setFirstChild (in nsIAccessible aAccFirstChild); */
  NS_IMETHOD SetFirstChild(nsIAccessible *aAccFirstChild) = 0;

  /* [noscript] void setNextSibling (in nsIAccessible aAccNextSibling); */
  NS_IMETHOD SetNextSibling(nsIAccessible *aAccNextSibling) = 0;

  /**
   * Set the child count to -1 (unknown) and null out cached child pointers
   */
  /* [noscript] void invalidateChildren (); */
  NS_IMETHOD InvalidateChildren(void) = 0;

  /* [noscript] void fireToolkitEvent (in unsigned long aEvent, in nsIAccessible aTarget, in voidPtr aData); */
  NS_IMETHOD FireToolkitEvent(PRUint32 aEvent, nsIAccessible *aTarget, void * aData) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSPIACCESSIBLE \
  NS_IMETHOD SetParent(nsIAccessible *aAccParent); \
  NS_IMETHOD SetFirstChild(nsIAccessible *aAccFirstChild); \
  NS_IMETHOD SetNextSibling(nsIAccessible *aAccNextSibling); \
  NS_IMETHOD InvalidateChildren(void); \
  NS_IMETHOD FireToolkitEvent(PRUint32 aEvent, nsIAccessible *aTarget, void * aData); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSPIACCESSIBLE(_to) \
  NS_IMETHOD SetParent(nsIAccessible *aAccParent) { return _to SetParent(aAccParent); } \
  NS_IMETHOD SetFirstChild(nsIAccessible *aAccFirstChild) { return _to SetFirstChild(aAccFirstChild); } \
  NS_IMETHOD SetNextSibling(nsIAccessible *aAccNextSibling) { return _to SetNextSibling(aAccNextSibling); } \
  NS_IMETHOD InvalidateChildren(void) { return _to InvalidateChildren(); } \
  NS_IMETHOD FireToolkitEvent(PRUint32 aEvent, nsIAccessible *aTarget, void * aData) { return _to FireToolkitEvent(aEvent, aTarget, aData); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSPIACCESSIBLE(_to) \
  NS_IMETHOD SetParent(nsIAccessible *aAccParent) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetParent(aAccParent); } \
  NS_IMETHOD SetFirstChild(nsIAccessible *aAccFirstChild) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFirstChild(aAccFirstChild); } \
  NS_IMETHOD SetNextSibling(nsIAccessible *aAccNextSibling) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNextSibling(aAccNextSibling); } \
  NS_IMETHOD InvalidateChildren(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->InvalidateChildren(); } \
  NS_IMETHOD FireToolkitEvent(PRUint32 aEvent, nsIAccessible *aTarget, void * aData) { return !_to ? NS_ERROR_NULL_POINTER : _to->FireToolkitEvent(aEvent, aTarget, aData); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsPIAccessible
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSPIACCESSIBLE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsPIAccessible)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* [noscript] void setParent (in nsIAccessible aAccParent); */
NS_IMETHODIMP _MYCLASS_::SetParent(nsIAccessible *aAccParent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void setFirstChild (in nsIAccessible aAccFirstChild); */
NS_IMETHODIMP _MYCLASS_::SetFirstChild(nsIAccessible *aAccFirstChild)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void setNextSibling (in nsIAccessible aAccNextSibling); */
NS_IMETHODIMP _MYCLASS_::SetNextSibling(nsIAccessible *aAccNextSibling)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void invalidateChildren (); */
NS_IMETHODIMP _MYCLASS_::InvalidateChildren()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void fireToolkitEvent (in unsigned long aEvent, in nsIAccessible aTarget, in voidPtr aData); */
NS_IMETHODIMP _MYCLASS_::FireToolkitEvent(PRUint32 aEvent, nsIAccessible *aTarget, void * aData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsPIAccessible_h__ */
