/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSearchScopeTerm.idl
 */

#ifndef __gen_nsIMsgSearchScopeTerm_h__
#define __gen_nsIMsgSearchScopeTerm_h__


#ifndef __gen_nsIMsgSearchSession_h__
#include "nsIMsgSearchSession.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsILocalFile; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsILineInputStream; /* forward declaration */


/* starting interface:    nsIMsgSearchScopeTerm */
#define NS_IMSGSEARCHSCOPETERM_IID_STR "10f5c44f-5a11-44e0-9b6b-4db81ba97963"

#define NS_IMSGSEARCHSCOPETERM_IID \
  {0x10f5c44f, 0x5a11, 0x44e0, \
    { 0x9b, 0x6b, 0x4d, 0xb8, 0x1b, 0xa9, 0x79, 0x63 }}

class NS_NO_VTABLE nsIMsgSearchScopeTerm : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHSCOPETERM_IID)

  /* readonly attribute nsILocalFile mailFile; */
  NS_IMETHOD GetMailFile(nsILocalFile * *aMailFile) = 0;

  /* attribute nsIInputStream inputStream; */
  NS_IMETHOD GetInputStream(nsIInputStream * *aInputStream) = 0;
  NS_IMETHOD SetInputStream(nsIInputStream * aInputStream) = 0;

  /* readonly attribute nsIMsgFolder folder; */
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) = 0;

  /* readonly attribute nsIMsgSearchSession searchSession; */
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHSCOPETERM \
  NS_IMETHOD GetMailFile(nsILocalFile * *aMailFile); \
  NS_IMETHOD GetInputStream(nsIInputStream * *aInputStream); \
  NS_IMETHOD SetInputStream(nsIInputStream * aInputStream); \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder); \
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHSCOPETERM(_to) \
  NS_IMETHOD GetMailFile(nsILocalFile * *aMailFile) { return _to GetMailFile(aMailFile); } \
  NS_IMETHOD GetInputStream(nsIInputStream * *aInputStream) { return _to GetInputStream(aInputStream); } \
  NS_IMETHOD SetInputStream(nsIInputStream * aInputStream) { return _to SetInputStream(aInputStream); } \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) { return _to GetFolder(aFolder); } \
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession) { return _to GetSearchSession(aSearchSession); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHSCOPETERM(_to) \
  NS_IMETHOD GetMailFile(nsILocalFile * *aMailFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailFile(aMailFile); } \
  NS_IMETHOD GetInputStream(nsIInputStream * *aInputStream) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInputStream(aInputStream); } \
  NS_IMETHOD SetInputStream(nsIInputStream * aInputStream) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetInputStream(aInputStream); } \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolder(aFolder); } \
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchSession(aSearchSession); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchScopeTerm : public nsIMsgSearchScopeTerm
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHSCOPETERM

  nsMsgSearchScopeTerm();

private:
  ~nsMsgSearchScopeTerm();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchScopeTerm, nsIMsgSearchScopeTerm)

nsMsgSearchScopeTerm::nsMsgSearchScopeTerm()
{
  /* member initializers and constructor code */
}

nsMsgSearchScopeTerm::~nsMsgSearchScopeTerm()
{
  /* destructor code */
}

/* readonly attribute nsILocalFile mailFile; */
NS_IMETHODIMP nsMsgSearchScopeTerm::GetMailFile(nsILocalFile * *aMailFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIInputStream inputStream; */
NS_IMETHODIMP nsMsgSearchScopeTerm::GetInputStream(nsIInputStream * *aInputStream)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchScopeTerm::SetInputStream(nsIInputStream * aInputStream)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgFolder folder; */
NS_IMETHODIMP nsMsgSearchScopeTerm::GetFolder(nsIMsgFolder * *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgSearchSession searchSession; */
NS_IMETHODIMP nsMsgSearchScopeTerm::GetSearchSession(nsIMsgSearchSession * *aSearchSession)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchScopeTerm_h__ */
