/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIEncryptedSMIMEURIsSrvc.idl
 */

#ifndef __gen_nsIEncryptedSMIMEURIsSrvc_h__
#define __gen_nsIEncryptedSMIMEURIsSrvc_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIEncryptedSMIMEURIsService */
#define NS_IENCRYPTEDSMIMEURISSERVICE_IID_STR "f86e55c9-530b-483f-91a7-10fb5b852488"

#define NS_IENCRYPTEDSMIMEURISSERVICE_IID \
  {0xf86e55c9, 0x530b, 0x483f, \
    { 0x91, 0xa7, 0x10, 0xfb, 0x5b, 0x85, 0x24, 0x88 }}

class NS_NO_VTABLE nsIEncryptedSMIMEURIsService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IENCRYPTEDSMIMEURISSERVICE_IID)

  /* void rememberEncrypted (in AUTF8String uri); */
  NS_IMETHOD RememberEncrypted(const nsACString & uri) = 0;

  /* void forgetEncrypted (in AUTF8String uri); */
  NS_IMETHOD ForgetEncrypted(const nsACString & uri) = 0;

  /* boolean isEncrypted (in AUTF8String uri); */
  NS_IMETHOD IsEncrypted(const nsACString & uri, PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIENCRYPTEDSMIMEURISSERVICE \
  NS_IMETHOD RememberEncrypted(const nsACString & uri); \
  NS_IMETHOD ForgetEncrypted(const nsACString & uri); \
  NS_IMETHOD IsEncrypted(const nsACString & uri, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIENCRYPTEDSMIMEURISSERVICE(_to) \
  NS_IMETHOD RememberEncrypted(const nsACString & uri) { return _to RememberEncrypted(uri); } \
  NS_IMETHOD ForgetEncrypted(const nsACString & uri) { return _to ForgetEncrypted(uri); } \
  NS_IMETHOD IsEncrypted(const nsACString & uri, PRBool *_retval) { return _to IsEncrypted(uri, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIENCRYPTEDSMIMEURISSERVICE(_to) \
  NS_IMETHOD RememberEncrypted(const nsACString & uri) { return !_to ? NS_ERROR_NULL_POINTER : _to->RememberEncrypted(uri); } \
  NS_IMETHOD ForgetEncrypted(const nsACString & uri) { return !_to ? NS_ERROR_NULL_POINTER : _to->ForgetEncrypted(uri); } \
  NS_IMETHOD IsEncrypted(const nsACString & uri, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsEncrypted(uri, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsEncryptedSMIMEURIsService : public nsIEncryptedSMIMEURIsService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIENCRYPTEDSMIMEURISSERVICE

  nsEncryptedSMIMEURIsService();

private:
  ~nsEncryptedSMIMEURIsService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsEncryptedSMIMEURIsService, nsIEncryptedSMIMEURIsService)

nsEncryptedSMIMEURIsService::nsEncryptedSMIMEURIsService()
{
  /* member initializers and constructor code */
}

nsEncryptedSMIMEURIsService::~nsEncryptedSMIMEURIsService()
{
  /* destructor code */
}

/* void rememberEncrypted (in AUTF8String uri); */
NS_IMETHODIMP nsEncryptedSMIMEURIsService::RememberEncrypted(const nsACString & uri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void forgetEncrypted (in AUTF8String uri); */
NS_IMETHODIMP nsEncryptedSMIMEURIsService::ForgetEncrypted(const nsACString & uri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isEncrypted (in AUTF8String uri); */
NS_IMETHODIMP nsEncryptedSMIMEURIsService::IsEncrypted(const nsACString & uri, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIEncryptedSMIMEURIsSrvc_h__ */
