/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIJARChannel.idl
 */

#ifndef __gen_nsIJARChannel_h__
#define __gen_nsIJARChannel_h__


#ifndef __gen_nsIChannel_h__
#include "nsIChannel.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIJARChannel */
#define NS_IJARCHANNEL_IID_STR "c7e410d1-85f2-11d3-9f63-006008a6efe9"

#define NS_IJARCHANNEL_IID \
  {0xc7e410d1, 0x85f2, 0x11d3, \
    { 0x9f, 0x63, 0x00, 0x60, 0x08, 0xa6, 0xef, 0xe9 }}

class NS_NO_VTABLE nsIJARChannel : public nsIChannel {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IJARCHANNEL_IID)

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIJARCHANNEL \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIJARCHANNEL(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIJARCHANNEL(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsJARChannel : public nsIJARChannel
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIJARCHANNEL

  nsJARChannel();

private:
  ~nsJARChannel();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsJARChannel, nsIJARChannel)

nsJARChannel::nsJARChannel()
{
  /* member initializers and constructor code */
}

nsJARChannel::~nsJARChannel()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIJARChannel_MOZILLA_1_8_BRANCH */
#define NS_IJARCHANNEL_MOZILLA_1_8_BRANCH_IID_STR "2ee6d5ab-248b-47d0-aac3-3c29417e2164"

#define NS_IJARCHANNEL_MOZILLA_1_8_BRANCH_IID \
  {0x2ee6d5ab, 0x248b, 0x47d0, \
    { 0xaa, 0xc3, 0x3c, 0x29, 0x41, 0x7e, 0x21, 0x64 }}

class NS_NO_VTABLE nsIJARChannel_MOZILLA_1_8_BRANCH : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IJARCHANNEL_MOZILLA_1_8_BRANCH_IID)

  /**
     * Returns TRUE if the JAR file is not safe (if the content type reported
     * by the server for a remote JAR is not of an expected type).  Scripting,
     * redirects, and plugins should be disabled when loading from this
     * channel.
     */
  /* readonly attribute boolean isUnsafe; */
  NS_IMETHOD GetIsUnsafe(PRBool *aIsUnsafe) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIJARCHANNEL_MOZILLA_1_8_BRANCH \
  NS_IMETHOD GetIsUnsafe(PRBool *aIsUnsafe); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIJARCHANNEL_MOZILLA_1_8_BRANCH(_to) \
  NS_IMETHOD GetIsUnsafe(PRBool *aIsUnsafe) { return _to GetIsUnsafe(aIsUnsafe); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIJARCHANNEL_MOZILLA_1_8_BRANCH(_to) \
  NS_IMETHOD GetIsUnsafe(PRBool *aIsUnsafe) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsUnsafe(aIsUnsafe); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsJARChannel_MOZILLA_1_8_BRANCH : public nsIJARChannel_MOZILLA_1_8_BRANCH
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIJARCHANNEL_MOZILLA_1_8_BRANCH

  nsJARChannel_MOZILLA_1_8_BRANCH();

private:
  ~nsJARChannel_MOZILLA_1_8_BRANCH();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsJARChannel_MOZILLA_1_8_BRANCH, nsIJARChannel_MOZILLA_1_8_BRANCH)

nsJARChannel_MOZILLA_1_8_BRANCH::nsJARChannel_MOZILLA_1_8_BRANCH()
{
  /* member initializers and constructor code */
}

nsJARChannel_MOZILLA_1_8_BRANCH::~nsJARChannel_MOZILLA_1_8_BRANCH()
{
  /* destructor code */
}

/* readonly attribute boolean isUnsafe; */
NS_IMETHODIMP nsJARChannel_MOZILLA_1_8_BRANCH::GetIsUnsafe(PRBool *aIsUnsafe)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIJARChannel_h__ */
