/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImportMailboxDescriptor.idl
 */

#ifndef __gen_nsIImportMailboxDescriptor_h__
#define __gen_nsIImportMailboxDescriptor_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFileSpec; /* forward declaration */


/* starting interface:    nsIImportMailboxDescriptor */
#define NS_IIMPORTMAILBOXDESCRIPTOR_IID_STR "d92056c0-184d-11d3-a206-00a0cc26da63"

#define NS_IIMPORTMAILBOXDESCRIPTOR_IID \
  {0xd92056c0, 0x184d, 0x11d3, \
    { 0xa2, 0x06, 0x00, 0xa0, 0xcc, 0x26, 0xda, 0x63 }}

class NS_NO_VTABLE nsIImportMailboxDescriptor : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMPORTMAILBOXDESCRIPTOR_IID)

  /* attribute unsigned long identifier; */
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier) = 0;
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier) = 0;

  /* attribute unsigned long depth; */
  NS_IMETHOD GetDepth(PRUint32 *aDepth) = 0;
  NS_IMETHOD SetDepth(PRUint32 aDepth) = 0;

  /* attribute unsigned long size; */
  NS_IMETHOD GetSize(PRUint32 *aSize) = 0;
  NS_IMETHOD SetSize(PRUint32 aSize) = 0;

  /* wstring GetDisplayName (); */
  NS_IMETHOD GetDisplayName(PRUnichar **_retval) = 0;

  /* void SetDisplayName ([const] in wstring name); */
  NS_IMETHOD SetDisplayName(const PRUnichar *name) = 0;

  /* attribute boolean import; */
  NS_IMETHOD GetImport(PRBool *aImport) = 0;
  NS_IMETHOD SetImport(PRBool aImport) = 0;

  /* readonly attribute nsIFileSpec fileSpec; */
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTMAILBOXDESCRIPTOR \
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier); \
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier); \
  NS_IMETHOD GetDepth(PRUint32 *aDepth); \
  NS_IMETHOD SetDepth(PRUint32 aDepth); \
  NS_IMETHOD GetSize(PRUint32 *aSize); \
  NS_IMETHOD SetSize(PRUint32 aSize); \
  NS_IMETHOD GetDisplayName(PRUnichar **_retval); \
  NS_IMETHOD SetDisplayName(const PRUnichar *name); \
  NS_IMETHOD GetImport(PRBool *aImport); \
  NS_IMETHOD SetImport(PRBool aImport); \
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTMAILBOXDESCRIPTOR(_to) \
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier) { return _to GetIdentifier(aIdentifier); } \
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier) { return _to SetIdentifier(aIdentifier); } \
  NS_IMETHOD GetDepth(PRUint32 *aDepth) { return _to GetDepth(aDepth); } \
  NS_IMETHOD SetDepth(PRUint32 aDepth) { return _to SetDepth(aDepth); } \
  NS_IMETHOD GetSize(PRUint32 *aSize) { return _to GetSize(aSize); } \
  NS_IMETHOD SetSize(PRUint32 aSize) { return _to SetSize(aSize); } \
  NS_IMETHOD GetDisplayName(PRUnichar **_retval) { return _to GetDisplayName(_retval); } \
  NS_IMETHOD SetDisplayName(const PRUnichar *name) { return _to SetDisplayName(name); } \
  NS_IMETHOD GetImport(PRBool *aImport) { return _to GetImport(aImport); } \
  NS_IMETHOD SetImport(PRBool aImport) { return _to SetImport(aImport); } \
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec) { return _to GetFileSpec(aFileSpec); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTMAILBOXDESCRIPTOR(_to) \
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIdentifier(aIdentifier); } \
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIdentifier(aIdentifier); } \
  NS_IMETHOD GetDepth(PRUint32 *aDepth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDepth(aDepth); } \
  NS_IMETHOD SetDepth(PRUint32 aDepth) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDepth(aDepth); } \
  NS_IMETHOD GetSize(PRUint32 *aSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSize(aSize); } \
  NS_IMETHOD SetSize(PRUint32 aSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSize(aSize); } \
  NS_IMETHOD GetDisplayName(PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDisplayName(_retval); } \
  NS_IMETHOD SetDisplayName(const PRUnichar *name) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDisplayName(name); } \
  NS_IMETHOD GetImport(PRBool *aImport) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImport(aImport); } \
  NS_IMETHOD SetImport(PRBool aImport) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImport(aImport); } \
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFileSpec(aFileSpec); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportMailboxDescriptor : public nsIImportMailboxDescriptor
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTMAILBOXDESCRIPTOR

  nsImportMailboxDescriptor();

private:
  ~nsImportMailboxDescriptor();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportMailboxDescriptor, nsIImportMailboxDescriptor)

nsImportMailboxDescriptor::nsImportMailboxDescriptor()
{
  /* member initializers and constructor code */
}

nsImportMailboxDescriptor::~nsImportMailboxDescriptor()
{
  /* destructor code */
}

/* attribute unsigned long identifier; */
NS_IMETHODIMP nsImportMailboxDescriptor::GetIdentifier(PRUint32 *aIdentifier)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportMailboxDescriptor::SetIdentifier(PRUint32 aIdentifier)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long depth; */
NS_IMETHODIMP nsImportMailboxDescriptor::GetDepth(PRUint32 *aDepth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportMailboxDescriptor::SetDepth(PRUint32 aDepth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long size; */
NS_IMETHODIMP nsImportMailboxDescriptor::GetSize(PRUint32 *aSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportMailboxDescriptor::SetSize(PRUint32 aSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetDisplayName (); */
NS_IMETHODIMP nsImportMailboxDescriptor::GetDisplayName(PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetDisplayName ([const] in wstring name); */
NS_IMETHODIMP nsImportMailboxDescriptor::SetDisplayName(const PRUnichar *name)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean import; */
NS_IMETHODIMP nsImportMailboxDescriptor::GetImport(PRBool *aImport)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportMailboxDescriptor::SetImport(PRBool aImport)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIFileSpec fileSpec; */
NS_IMETHODIMP nsImportMailboxDescriptor::GetFileSpec(nsIFileSpec * *aFileSpec)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

/*
	The default implementation can be obtained from
	nsIImportService::CreateNewMailboxDescriptor();
	
	You should only be interested in using this class if you implement
	the nsIImportMail interface in which case, just using the service to
	create new ones should work fine for you.  If not, implement your
	own.
*/

#endif /* __gen_nsIImportMailboxDescriptor_h__ */
