/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsIAtom.idl"

interface nsIMsgFolder;
interface nsIRDFResource;
interface nsIMsgDBHdr;

typedef unsigned long folderListenerNotifyFlagValue;

[scriptable, uuid(1c8e6a86-ae35-4c95-8e43-b2e98d6d1574)]
interface nsIFolderListener : nsISupports {
  const folderListenerNotifyFlagValue added = 0x1;
  void OnItemAdded(in nsIRDFResource parentItem,
                   in nsISupports item);
  
  const folderListenerNotifyFlagValue removed = 0x2;
  void OnItemRemoved(in nsIRDFResource parentItem,
                     in nsISupports item);
  
  const folderListenerNotifyFlagValue propertyChanged = 0x4;
  void OnItemPropertyChanged(in nsIRDFResource item,
                             in nsIAtom property,
                             in string oldValue,
                             in string newValue);
  
  const folderListenerNotifyFlagValue intPropertyChanged = 0x8;
  void OnItemIntPropertyChanged(in nsIRDFResource item,
                                in nsIAtom property,
                                in long oldValue,
                                in long newValue);
  
  const folderListenerNotifyFlagValue boolPropertyChanged = 0x10;
  void OnItemBoolPropertyChanged(in nsIRDFResource item,
                                 in nsIAtom property,
                                 in boolean oldValue,
                                 in boolean newValue);
  
  const folderListenerNotifyFlagValue unicharPropertyChanged = 0x20;
  void OnItemUnicharPropertyChanged(in nsIRDFResource item,
                                    in nsIAtom property,
                                    in wstring oldValue,
                                    in wstring newValue);
  
  const folderListenerNotifyFlagValue propertyFlagChanged = 0x40;
  void OnItemPropertyFlagChanged(in nsIMsgDBHdr item,
                                 in nsIAtom property,
                                 in unsigned long oldFlag,
                                 in unsigned long newFlag);

  const folderListenerNotifyFlagValue event = 0x80;
  void OnItemEvent(in nsIMsgFolder item, in nsIAtom event);
  
  const folderListenerNotifyFlagValue all = 0xFFFFFFFF; 

  //	void OnFolderLoaded(in nsIMsgFolder aFolder);
  //	void OnDeleteOrMoveMessagesCompleted(in nsIMsgFolder aFolder);
};
