/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIAccessibleHyperLink.idl
 */

#ifndef __gen_nsIAccessibleHyperLink_h__
#define __gen_nsIAccessibleHyperLink_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIAccessible; /* forward declaration */


/* starting interface:    nsIAccessibleHyperLink */
#define NS_IACCESSIBLEHYPERLINK_IID_STR "a492c7d6-1dd1-11b2-9bc0-80614884799a"

#define NS_IACCESSIBLEHYPERLINK_IID \
  {0xa492c7d6, 0x1dd1, 0x11b2, \
    { 0x9b, 0xc0, 0x80, 0x61, 0x48, 0x84, 0x79, 0x9a }}

class NS_NO_VTABLE nsIAccessibleHyperLink : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IACCESSIBLEHYPERLINK_IID)

  /* readonly attribute long anchors; */
  NS_IMETHOD GetAnchors(PRInt32 *aAnchors) = 0;

  /* readonly attribute long startIndex; */
  NS_IMETHOD GetStartIndex(PRInt32 *aStartIndex) = 0;

  /* readonly attribute long endIndex; */
  NS_IMETHOD GetEndIndex(PRInt32 *aEndIndex) = 0;

  /* nsIURI getURI (in long i); */
  NS_IMETHOD GetURI(PRInt32 i, nsIURI **_retval) = 0;

  /* nsIAccessible getObject (in long i); */
  NS_IMETHOD GetObject(PRInt32 i, nsIAccessible **_retval) = 0;

  /* boolean isValid (); */
  NS_IMETHOD IsValid(PRBool *_retval) = 0;

  /* boolean isSelected (); */
  NS_IMETHOD IsSelected(PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIACCESSIBLEHYPERLINK \
  NS_IMETHOD GetAnchors(PRInt32 *aAnchors); \
  NS_IMETHOD GetStartIndex(PRInt32 *aStartIndex); \
  NS_IMETHOD GetEndIndex(PRInt32 *aEndIndex); \
  NS_IMETHOD GetURI(PRInt32 i, nsIURI **_retval); \
  NS_IMETHOD GetObject(PRInt32 i, nsIAccessible **_retval); \
  NS_IMETHOD IsValid(PRBool *_retval); \
  NS_IMETHOD IsSelected(PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIACCESSIBLEHYPERLINK(_to) \
  NS_IMETHOD GetAnchors(PRInt32 *aAnchors) { return _to GetAnchors(aAnchors); } \
  NS_IMETHOD GetStartIndex(PRInt32 *aStartIndex) { return _to GetStartIndex(aStartIndex); } \
  NS_IMETHOD GetEndIndex(PRInt32 *aEndIndex) { return _to GetEndIndex(aEndIndex); } \
  NS_IMETHOD GetURI(PRInt32 i, nsIURI **_retval) { return _to GetURI(i, _retval); } \
  NS_IMETHOD GetObject(PRInt32 i, nsIAccessible **_retval) { return _to GetObject(i, _retval); } \
  NS_IMETHOD IsValid(PRBool *_retval) { return _to IsValid(_retval); } \
  NS_IMETHOD IsSelected(PRBool *_retval) { return _to IsSelected(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIACCESSIBLEHYPERLINK(_to) \
  NS_IMETHOD GetAnchors(PRInt32 *aAnchors) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAnchors(aAnchors); } \
  NS_IMETHOD GetStartIndex(PRInt32 *aStartIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStartIndex(aStartIndex); } \
  NS_IMETHOD GetEndIndex(PRInt32 *aEndIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEndIndex(aEndIndex); } \
  NS_IMETHOD GetURI(PRInt32 i, nsIURI **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetURI(i, _retval); } \
  NS_IMETHOD GetObject(PRInt32 i, nsIAccessible **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetObject(i, _retval); } \
  NS_IMETHOD IsValid(PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsValid(_retval); } \
  NS_IMETHOD IsSelected(PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsSelected(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAccessibleHyperLink : public nsIAccessibleHyperLink
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIACCESSIBLEHYPERLINK

  nsAccessibleHyperLink();

private:
  ~nsAccessibleHyperLink();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAccessibleHyperLink, nsIAccessibleHyperLink)

nsAccessibleHyperLink::nsAccessibleHyperLink()
{
  /* member initializers and constructor code */
}

nsAccessibleHyperLink::~nsAccessibleHyperLink()
{
  /* destructor code */
}

/* readonly attribute long anchors; */
NS_IMETHODIMP nsAccessibleHyperLink::GetAnchors(PRInt32 *aAnchors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long startIndex; */
NS_IMETHODIMP nsAccessibleHyperLink::GetStartIndex(PRInt32 *aStartIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long endIndex; */
NS_IMETHODIMP nsAccessibleHyperLink::GetEndIndex(PRInt32 *aEndIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI getURI (in long i); */
NS_IMETHODIMP nsAccessibleHyperLink::GetURI(PRInt32 i, nsIURI **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIAccessible getObject (in long i); */
NS_IMETHODIMP nsAccessibleHyperLink::GetObject(PRInt32 i, nsIAccessible **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isValid (); */
NS_IMETHODIMP nsAccessibleHyperLink::IsValid(PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isSelected (); */
NS_IMETHODIMP nsAccessibleHyperLink::IsSelected(PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAccessibleHyperLink_h__ */
