/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImportMimeEncode.idl
 */

#ifndef __gen_nsIImportMimeEncode_h__
#define __gen_nsIImportMimeEncode_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFileSpec; /* forward declaration */


/* starting interface:    nsIImportMimeEncode */
#define NS_IIMPORTMIMEENCODE_IID_STR "455ca0a0-8de2-11d3-a206-00a0cc26da63"

#define NS_IIMPORTMIMEENCODE_IID \
  {0x455ca0a0, 0x8de2, 0x11d3, \
    { 0xa2, 0x06, 0x00, 0xa0, 0xcc, 0x26, 0xda, 0x63 }}

class NS_NO_VTABLE nsIImportMimeEncode : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMPORTMIMEENCODE_IID)

  /* void EncodeFile (in nsIFileSpec inFile, in nsIFileSpec outFile, [const] in string fileName, [const] in string mimeType); */
  NS_IMETHOD EncodeFile(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType) = 0;

  /* boolean DoWork (out boolean done); */
  NS_IMETHOD DoWork(PRBool *done, PRBool *_retval) = 0;

  /* long NumBytesProcessed (); */
  NS_IMETHOD NumBytesProcessed(PRInt32 *_retval) = 0;

  /* boolean DoEncoding (); */
  NS_IMETHOD DoEncoding(PRBool *_retval) = 0;

  /* void Initialize (in nsIFileSpec inFile, in nsIFileSpec outFile, [const] in string fileName, [const] in string mimeType); */
  NS_IMETHOD Initialize(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTMIMEENCODE \
  NS_IMETHOD EncodeFile(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType); \
  NS_IMETHOD DoWork(PRBool *done, PRBool *_retval); \
  NS_IMETHOD NumBytesProcessed(PRInt32 *_retval); \
  NS_IMETHOD DoEncoding(PRBool *_retval); \
  NS_IMETHOD Initialize(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTMIMEENCODE(_to) \
  NS_IMETHOD EncodeFile(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType) { return _to EncodeFile(inFile, outFile, fileName, mimeType); } \
  NS_IMETHOD DoWork(PRBool *done, PRBool *_retval) { return _to DoWork(done, _retval); } \
  NS_IMETHOD NumBytesProcessed(PRInt32 *_retval) { return _to NumBytesProcessed(_retval); } \
  NS_IMETHOD DoEncoding(PRBool *_retval) { return _to DoEncoding(_retval); } \
  NS_IMETHOD Initialize(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType) { return _to Initialize(inFile, outFile, fileName, mimeType); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTMIMEENCODE(_to) \
  NS_IMETHOD EncodeFile(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType) { return !_to ? NS_ERROR_NULL_POINTER : _to->EncodeFile(inFile, outFile, fileName, mimeType); } \
  NS_IMETHOD DoWork(PRBool *done, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->DoWork(done, _retval); } \
  NS_IMETHOD NumBytesProcessed(PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->NumBytesProcessed(_retval); } \
  NS_IMETHOD DoEncoding(PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->DoEncoding(_retval); } \
  NS_IMETHOD Initialize(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initialize(inFile, outFile, fileName, mimeType); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportMimeEncode : public nsIImportMimeEncode
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTMIMEENCODE

  nsImportMimeEncode();

private:
  ~nsImportMimeEncode();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportMimeEncode, nsIImportMimeEncode)

nsImportMimeEncode::nsImportMimeEncode()
{
  /* member initializers and constructor code */
}

nsImportMimeEncode::~nsImportMimeEncode()
{
  /* destructor code */
}

/* void EncodeFile (in nsIFileSpec inFile, in nsIFileSpec outFile, [const] in string fileName, [const] in string mimeType); */
NS_IMETHODIMP nsImportMimeEncode::EncodeFile(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean DoWork (out boolean done); */
NS_IMETHODIMP nsImportMimeEncode::DoWork(PRBool *done, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long NumBytesProcessed (); */
NS_IMETHODIMP nsImportMimeEncode::NumBytesProcessed(PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean DoEncoding (); */
NS_IMETHODIMP nsImportMimeEncode::DoEncoding(PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void Initialize (in nsIFileSpec inFile, in nsIFileSpec outFile, [const] in string fileName, [const] in string mimeType); */
NS_IMETHODIMP nsImportMimeEncode::Initialize(nsIFileSpec *inFile, nsIFileSpec *outFile, const char *fileName, const char *mimeType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define NS_IMPORTMIMEENCODE_CID                      \
{ /* e4a1a340-8de2-11d3-a206-00a0cc26da63 */         \
    0xe4a1a340,                                      \
    0x8de2,                                          \
    0x11d3,                                          \
    {0xa2, 0x06, 0x00, 0xa0, 0xcc, 0x26, 0xda, 0x63} \
}

#endif /* __gen_nsIImportMimeEncode_h__ */
