/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImapServerSink.idl
 */

#ifndef __gen_nsIImapServerSink_h__
#define __gen_nsIImapServerSink_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */

class nsIMsgMailNewsUrl; /* forward declaration */

class nsIImapProtocol; /* forward declaration */

class nsIImapUrl; /* forward declaration */


/* starting interface:    nsIImapServerSink */
#define NS_IIMAPSERVERSINK_IID_STR "f61940a5-71d7-455a-8383-940d0b6a964b"

#define NS_IIMAPSERVERSINK_IID \
  {0xf61940a5, 0x71d7, 0x455a, \
    { 0x83, 0x83, 0x94, 0x0d, 0x0b, 0x6a, 0x96, 0x4b }}

class NS_NO_VTABLE nsIImapServerSink : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMAPSERVERSINK_IID)

  /* boolean possibleImapMailbox (in string folderPath, in wchar hierarchyDelim, in long boxFlags); */
  NS_IMETHOD PossibleImapMailbox(const char *folderPath, PRUnichar hierarchyDelim, PRInt32 boxFlags, PRBool *_retval) = 0;

  /* boolean folderNeedsACLInitialized (in string folderPath); */
  NS_IMETHOD FolderNeedsACLInitialized(const char *folderPath, PRBool *_retval) = 0;

  /* void addFolderRights (in string folderPath, in string userName, in string rights); */
  NS_IMETHOD AddFolderRights(const char *folderPath, const char *userName, const char *rights) = 0;

  /* void refreshFolderRights (in string folderPath); */
  NS_IMETHOD RefreshFolderRights(const char *folderPath) = 0;

  /* void discoveryDone (); */
  NS_IMETHOD DiscoveryDone(void) = 0;

  /* void onlineFolderDelete (in string aFolderName); */
  NS_IMETHOD OnlineFolderDelete(const char *aFolderName) = 0;

  /* void onlineFolderCreateFailed (in string aFolderName); */
  NS_IMETHOD OnlineFolderCreateFailed(const char *aFolderName) = 0;

  /* void onlineFolderRename (in nsIMsgWindow msgWindow, in string oldName, in string newName); */
  NS_IMETHOD OnlineFolderRename(nsIMsgWindow *msgWindow, const char *oldName, const char *newName) = 0;

  /* void folderIsNoSelect (in string aFolderName, out boolean aResult); */
  NS_IMETHOD FolderIsNoSelect(const char *aFolderName, PRBool *aResult) = 0;

  /* void setFolderAdminURL (in string aFolderName, in string adminUrl); */
  NS_IMETHOD SetFolderAdminURL(const char *aFolderName, const char *adminUrl) = 0;

  /* boolean folderVerifiedOnline (in string aFolderName); */
  NS_IMETHOD FolderVerifiedOnline(const char *aFolderName, PRBool *_retval) = 0;

  /* void setCapability (in unsigned long capability); */
  NS_IMETHOD SetCapability(PRUint32 capability) = 0;

  /* void loadNextQueuedUrl (in nsIImapProtocol aProtocol, out boolean urlRun); */
  NS_IMETHOD LoadNextQueuedUrl(nsIImapProtocol *aProtocol, PRBool *urlRun) = 0;

  /* void retryUrl (in nsIImapUrl aImapUrl); */
  NS_IMETHOD RetryUrl(nsIImapUrl *aImapUrl) = 0;

  /* void abortQueuedUrls (); */
  NS_IMETHOD AbortQueuedUrls(void) = 0;

  /* void getImapStringByID (in long aMsgId, out wstring aString); */
  NS_IMETHOD GetImapStringByID(PRInt32 aMsgId, PRUnichar **aString) = 0;

  /* void formatStringWithHostNameByID (in long aMsgId, out wstring aString); */
  NS_IMETHOD FormatStringWithHostNameByID(PRInt32 aMsgId, PRUnichar **aString) = 0;

  /* void fEAlert (in wstring aString, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD FEAlert(const PRUnichar *aString, nsIMsgWindow *aMsgWindow) = 0;

  /* void fEAlertFromServer (in string aString, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD FEAlertFromServer(const char *aString, nsIMsgWindow *aMsgWindow) = 0;

  /* void commitNamespaces (); */
  NS_IMETHOD CommitNamespaces(void) = 0;

  /* void promptForPassword (out string aString, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD PromptForPassword(char **aString, nsIMsgWindow *aMsgWindow) = 0;

  /* attribute boolean userAuthenticated; */
  NS_IMETHOD GetUserAuthenticated(PRBool *aUserAuthenticated) = 0;
  NS_IMETHOD SetUserAuthenticated(PRBool aUserAuthenticated) = 0;

  /* void setMailServerUrls (in string manageMailAccount, in string manageLists, in string manageFilters); */
  NS_IMETHOD SetMailServerUrls(const char *manageMailAccount, const char *manageLists, const char *manageFilters) = 0;

  /* void RemoveChannelFromUrl (in nsIMsgMailNewsUrl aUrl, in unsigned long statusCode); */
  NS_IMETHOD RemoveChannelFromUrl(nsIMsgMailNewsUrl *aUrl, PRUint32 statusCode) = 0;

  /* readonly attribute string arbitraryHeaders; */
  NS_IMETHOD GetArbitraryHeaders(char * *aArbitraryHeaders) = 0;

  /* void forgetPassword (); */
  NS_IMETHOD ForgetPassword(void) = 0;

  /* readonly attribute boolean showAttachmentsInline; */
  NS_IMETHOD GetShowAttachmentsInline(PRBool *aShowAttachmentsInline) = 0;

  /* string cramMD5Hash (in string decodedChallenge, in string key); */
  NS_IMETHOD CramMD5Hash(const char *decodedChallenge, const char *key, char **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPSERVERSINK \
  NS_IMETHOD PossibleImapMailbox(const char *folderPath, PRUnichar hierarchyDelim, PRInt32 boxFlags, PRBool *_retval); \
  NS_IMETHOD FolderNeedsACLInitialized(const char *folderPath, PRBool *_retval); \
  NS_IMETHOD AddFolderRights(const char *folderPath, const char *userName, const char *rights); \
  NS_IMETHOD RefreshFolderRights(const char *folderPath); \
  NS_IMETHOD DiscoveryDone(void); \
  NS_IMETHOD OnlineFolderDelete(const char *aFolderName); \
  NS_IMETHOD OnlineFolderCreateFailed(const char *aFolderName); \
  NS_IMETHOD OnlineFolderRename(nsIMsgWindow *msgWindow, const char *oldName, const char *newName); \
  NS_IMETHOD FolderIsNoSelect(const char *aFolderName, PRBool *aResult); \
  NS_IMETHOD SetFolderAdminURL(const char *aFolderName, const char *adminUrl); \
  NS_IMETHOD FolderVerifiedOnline(const char *aFolderName, PRBool *_retval); \
  NS_IMETHOD SetCapability(PRUint32 capability); \
  NS_IMETHOD LoadNextQueuedUrl(nsIImapProtocol *aProtocol, PRBool *urlRun); \
  NS_IMETHOD RetryUrl(nsIImapUrl *aImapUrl); \
  NS_IMETHOD AbortQueuedUrls(void); \
  NS_IMETHOD GetImapStringByID(PRInt32 aMsgId, PRUnichar **aString); \
  NS_IMETHOD FormatStringWithHostNameByID(PRInt32 aMsgId, PRUnichar **aString); \
  NS_IMETHOD FEAlert(const PRUnichar *aString, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD FEAlertFromServer(const char *aString, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD CommitNamespaces(void); \
  NS_IMETHOD PromptForPassword(char **aString, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD GetUserAuthenticated(PRBool *aUserAuthenticated); \
  NS_IMETHOD SetUserAuthenticated(PRBool aUserAuthenticated); \
  NS_IMETHOD SetMailServerUrls(const char *manageMailAccount, const char *manageLists, const char *manageFilters); \
  NS_IMETHOD RemoveChannelFromUrl(nsIMsgMailNewsUrl *aUrl, PRUint32 statusCode); \
  NS_IMETHOD GetArbitraryHeaders(char * *aArbitraryHeaders); \
  NS_IMETHOD ForgetPassword(void); \
  NS_IMETHOD GetShowAttachmentsInline(PRBool *aShowAttachmentsInline); \
  NS_IMETHOD CramMD5Hash(const char *decodedChallenge, const char *key, char **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPSERVERSINK(_to) \
  NS_IMETHOD PossibleImapMailbox(const char *folderPath, PRUnichar hierarchyDelim, PRInt32 boxFlags, PRBool *_retval) { return _to PossibleImapMailbox(folderPath, hierarchyDelim, boxFlags, _retval); } \
  NS_IMETHOD FolderNeedsACLInitialized(const char *folderPath, PRBool *_retval) { return _to FolderNeedsACLInitialized(folderPath, _retval); } \
  NS_IMETHOD AddFolderRights(const char *folderPath, const char *userName, const char *rights) { return _to AddFolderRights(folderPath, userName, rights); } \
  NS_IMETHOD RefreshFolderRights(const char *folderPath) { return _to RefreshFolderRights(folderPath); } \
  NS_IMETHOD DiscoveryDone(void) { return _to DiscoveryDone(); } \
  NS_IMETHOD OnlineFolderDelete(const char *aFolderName) { return _to OnlineFolderDelete(aFolderName); } \
  NS_IMETHOD OnlineFolderCreateFailed(const char *aFolderName) { return _to OnlineFolderCreateFailed(aFolderName); } \
  NS_IMETHOD OnlineFolderRename(nsIMsgWindow *msgWindow, const char *oldName, const char *newName) { return _to OnlineFolderRename(msgWindow, oldName, newName); } \
  NS_IMETHOD FolderIsNoSelect(const char *aFolderName, PRBool *aResult) { return _to FolderIsNoSelect(aFolderName, aResult); } \
  NS_IMETHOD SetFolderAdminURL(const char *aFolderName, const char *adminUrl) { return _to SetFolderAdminURL(aFolderName, adminUrl); } \
  NS_IMETHOD FolderVerifiedOnline(const char *aFolderName, PRBool *_retval) { return _to FolderVerifiedOnline(aFolderName, _retval); } \
  NS_IMETHOD SetCapability(PRUint32 capability) { return _to SetCapability(capability); } \
  NS_IMETHOD LoadNextQueuedUrl(nsIImapProtocol *aProtocol, PRBool *urlRun) { return _to LoadNextQueuedUrl(aProtocol, urlRun); } \
  NS_IMETHOD RetryUrl(nsIImapUrl *aImapUrl) { return _to RetryUrl(aImapUrl); } \
  NS_IMETHOD AbortQueuedUrls(void) { return _to AbortQueuedUrls(); } \
  NS_IMETHOD GetImapStringByID(PRInt32 aMsgId, PRUnichar **aString) { return _to GetImapStringByID(aMsgId, aString); } \
  NS_IMETHOD FormatStringWithHostNameByID(PRInt32 aMsgId, PRUnichar **aString) { return _to FormatStringWithHostNameByID(aMsgId, aString); } \
  NS_IMETHOD FEAlert(const PRUnichar *aString, nsIMsgWindow *aMsgWindow) { return _to FEAlert(aString, aMsgWindow); } \
  NS_IMETHOD FEAlertFromServer(const char *aString, nsIMsgWindow *aMsgWindow) { return _to FEAlertFromServer(aString, aMsgWindow); } \
  NS_IMETHOD CommitNamespaces(void) { return _to CommitNamespaces(); } \
  NS_IMETHOD PromptForPassword(char **aString, nsIMsgWindow *aMsgWindow) { return _to PromptForPassword(aString, aMsgWindow); } \
  NS_IMETHOD GetUserAuthenticated(PRBool *aUserAuthenticated) { return _to GetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD SetUserAuthenticated(PRBool aUserAuthenticated) { return _to SetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD SetMailServerUrls(const char *manageMailAccount, const char *manageLists, const char *manageFilters) { return _to SetMailServerUrls(manageMailAccount, manageLists, manageFilters); } \
  NS_IMETHOD RemoveChannelFromUrl(nsIMsgMailNewsUrl *aUrl, PRUint32 statusCode) { return _to RemoveChannelFromUrl(aUrl, statusCode); } \
  NS_IMETHOD GetArbitraryHeaders(char * *aArbitraryHeaders) { return _to GetArbitraryHeaders(aArbitraryHeaders); } \
  NS_IMETHOD ForgetPassword(void) { return _to ForgetPassword(); } \
  NS_IMETHOD GetShowAttachmentsInline(PRBool *aShowAttachmentsInline) { return _to GetShowAttachmentsInline(aShowAttachmentsInline); } \
  NS_IMETHOD CramMD5Hash(const char *decodedChallenge, const char *key, char **_retval) { return _to CramMD5Hash(decodedChallenge, key, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPSERVERSINK(_to) \
  NS_IMETHOD PossibleImapMailbox(const char *folderPath, PRUnichar hierarchyDelim, PRInt32 boxFlags, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->PossibleImapMailbox(folderPath, hierarchyDelim, boxFlags, _retval); } \
  NS_IMETHOD FolderNeedsACLInitialized(const char *folderPath, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderNeedsACLInitialized(folderPath, _retval); } \
  NS_IMETHOD AddFolderRights(const char *folderPath, const char *userName, const char *rights) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddFolderRights(folderPath, userName, rights); } \
  NS_IMETHOD RefreshFolderRights(const char *folderPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->RefreshFolderRights(folderPath); } \
  NS_IMETHOD DiscoveryDone(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->DiscoveryDone(); } \
  NS_IMETHOD OnlineFolderDelete(const char *aFolderName) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnlineFolderDelete(aFolderName); } \
  NS_IMETHOD OnlineFolderCreateFailed(const char *aFolderName) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnlineFolderCreateFailed(aFolderName); } \
  NS_IMETHOD OnlineFolderRename(nsIMsgWindow *msgWindow, const char *oldName, const char *newName) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnlineFolderRename(msgWindow, oldName, newName); } \
  NS_IMETHOD FolderIsNoSelect(const char *aFolderName, PRBool *aResult) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderIsNoSelect(aFolderName, aResult); } \
  NS_IMETHOD SetFolderAdminURL(const char *aFolderName, const char *adminUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderAdminURL(aFolderName, adminUrl); } \
  NS_IMETHOD FolderVerifiedOnline(const char *aFolderName, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderVerifiedOnline(aFolderName, _retval); } \
  NS_IMETHOD SetCapability(PRUint32 capability) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCapability(capability); } \
  NS_IMETHOD LoadNextQueuedUrl(nsIImapProtocol *aProtocol, PRBool *urlRun) { return !_to ? NS_ERROR_NULL_POINTER : _to->LoadNextQueuedUrl(aProtocol, urlRun); } \
  NS_IMETHOD RetryUrl(nsIImapUrl *aImapUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->RetryUrl(aImapUrl); } \
  NS_IMETHOD AbortQueuedUrls(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->AbortQueuedUrls(); } \
  NS_IMETHOD GetImapStringByID(PRInt32 aMsgId, PRUnichar **aString) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImapStringByID(aMsgId, aString); } \
  NS_IMETHOD FormatStringWithHostNameByID(PRInt32 aMsgId, PRUnichar **aString) { return !_to ? NS_ERROR_NULL_POINTER : _to->FormatStringWithHostNameByID(aMsgId, aString); } \
  NS_IMETHOD FEAlert(const PRUnichar *aString, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->FEAlert(aString, aMsgWindow); } \
  NS_IMETHOD FEAlertFromServer(const char *aString, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->FEAlertFromServer(aString, aMsgWindow); } \
  NS_IMETHOD CommitNamespaces(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CommitNamespaces(); } \
  NS_IMETHOD PromptForPassword(char **aString, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->PromptForPassword(aString, aMsgWindow); } \
  NS_IMETHOD GetUserAuthenticated(PRBool *aUserAuthenticated) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD SetUserAuthenticated(PRBool aUserAuthenticated) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD SetMailServerUrls(const char *manageMailAccount, const char *manageLists, const char *manageFilters) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMailServerUrls(manageMailAccount, manageLists, manageFilters); } \
  NS_IMETHOD RemoveChannelFromUrl(nsIMsgMailNewsUrl *aUrl, PRUint32 statusCode) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveChannelFromUrl(aUrl, statusCode); } \
  NS_IMETHOD GetArbitraryHeaders(char * *aArbitraryHeaders) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArbitraryHeaders(aArbitraryHeaders); } \
  NS_IMETHOD ForgetPassword(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ForgetPassword(); } \
  NS_IMETHOD GetShowAttachmentsInline(PRBool *aShowAttachmentsInline) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShowAttachmentsInline(aShowAttachmentsInline); } \
  NS_IMETHOD CramMD5Hash(const char *decodedChallenge, const char *key, char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CramMD5Hash(decodedChallenge, key, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapServerSink : public nsIImapServerSink
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPSERVERSINK

  nsImapServerSink();

private:
  ~nsImapServerSink();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapServerSink, nsIImapServerSink)

nsImapServerSink::nsImapServerSink()
{
  /* member initializers and constructor code */
}

nsImapServerSink::~nsImapServerSink()
{
  /* destructor code */
}

/* boolean possibleImapMailbox (in string folderPath, in wchar hierarchyDelim, in long boxFlags); */
NS_IMETHODIMP nsImapServerSink::PossibleImapMailbox(const char *folderPath, PRUnichar hierarchyDelim, PRInt32 boxFlags, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean folderNeedsACLInitialized (in string folderPath); */
NS_IMETHODIMP nsImapServerSink::FolderNeedsACLInitialized(const char *folderPath, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addFolderRights (in string folderPath, in string userName, in string rights); */
NS_IMETHODIMP nsImapServerSink::AddFolderRights(const char *folderPath, const char *userName, const char *rights)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void refreshFolderRights (in string folderPath); */
NS_IMETHODIMP nsImapServerSink::RefreshFolderRights(const char *folderPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void discoveryDone (); */
NS_IMETHODIMP nsImapServerSink::DiscoveryDone()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onlineFolderDelete (in string aFolderName); */
NS_IMETHODIMP nsImapServerSink::OnlineFolderDelete(const char *aFolderName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onlineFolderCreateFailed (in string aFolderName); */
NS_IMETHODIMP nsImapServerSink::OnlineFolderCreateFailed(const char *aFolderName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onlineFolderRename (in nsIMsgWindow msgWindow, in string oldName, in string newName); */
NS_IMETHODIMP nsImapServerSink::OnlineFolderRename(nsIMsgWindow *msgWindow, const char *oldName, const char *newName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void folderIsNoSelect (in string aFolderName, out boolean aResult); */
NS_IMETHODIMP nsImapServerSink::FolderIsNoSelect(const char *aFolderName, PRBool *aResult)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setFolderAdminURL (in string aFolderName, in string adminUrl); */
NS_IMETHODIMP nsImapServerSink::SetFolderAdminURL(const char *aFolderName, const char *adminUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean folderVerifiedOnline (in string aFolderName); */
NS_IMETHODIMP nsImapServerSink::FolderVerifiedOnline(const char *aFolderName, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setCapability (in unsigned long capability); */
NS_IMETHODIMP nsImapServerSink::SetCapability(PRUint32 capability)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void loadNextQueuedUrl (in nsIImapProtocol aProtocol, out boolean urlRun); */
NS_IMETHODIMP nsImapServerSink::LoadNextQueuedUrl(nsIImapProtocol *aProtocol, PRBool *urlRun)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void retryUrl (in nsIImapUrl aImapUrl); */
NS_IMETHODIMP nsImapServerSink::RetryUrl(nsIImapUrl *aImapUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void abortQueuedUrls (); */
NS_IMETHODIMP nsImapServerSink::AbortQueuedUrls()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getImapStringByID (in long aMsgId, out wstring aString); */
NS_IMETHODIMP nsImapServerSink::GetImapStringByID(PRInt32 aMsgId, PRUnichar **aString)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void formatStringWithHostNameByID (in long aMsgId, out wstring aString); */
NS_IMETHODIMP nsImapServerSink::FormatStringWithHostNameByID(PRInt32 aMsgId, PRUnichar **aString)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void fEAlert (in wstring aString, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapServerSink::FEAlert(const PRUnichar *aString, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void fEAlertFromServer (in string aString, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapServerSink::FEAlertFromServer(const char *aString, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void commitNamespaces (); */
NS_IMETHODIMP nsImapServerSink::CommitNamespaces()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void promptForPassword (out string aString, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapServerSink::PromptForPassword(char **aString, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean userAuthenticated; */
NS_IMETHODIMP nsImapServerSink::GetUserAuthenticated(PRBool *aUserAuthenticated)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImapServerSink::SetUserAuthenticated(PRBool aUserAuthenticated)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setMailServerUrls (in string manageMailAccount, in string manageLists, in string manageFilters); */
NS_IMETHODIMP nsImapServerSink::SetMailServerUrls(const char *manageMailAccount, const char *manageLists, const char *manageFilters)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RemoveChannelFromUrl (in nsIMsgMailNewsUrl aUrl, in unsigned long statusCode); */
NS_IMETHODIMP nsImapServerSink::RemoveChannelFromUrl(nsIMsgMailNewsUrl *aUrl, PRUint32 statusCode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string arbitraryHeaders; */
NS_IMETHODIMP nsImapServerSink::GetArbitraryHeaders(char * *aArbitraryHeaders)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void forgetPassword (); */
NS_IMETHODIMP nsImapServerSink::ForgetPassword()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean showAttachmentsInline; */
NS_IMETHODIMP nsImapServerSink::GetShowAttachmentsInline(PRBool *aShowAttachmentsInline)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string cramMD5Hash (in string decodedChallenge, in string key); */
NS_IMETHODIMP nsImapServerSink::CramMD5Hash(const char *decodedChallenge, const char *key, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImapServerSink_h__ */
