/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIFolderListener.idl
 */

#ifndef __gen_nsIFolderListener_h__
#define __gen_nsIFolderListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIAtom_h__
#include "nsIAtom.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsIRDFResource; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

typedef PRUint32 folderListenerNotifyFlagValue;


/* starting interface:    nsIFolderListener */
#define NS_IFOLDERLISTENER_IID_STR "1c8e6a86-ae35-4c95-8e43-b2e98d6d1574"

#define NS_IFOLDERLISTENER_IID \
  {0x1c8e6a86, 0xae35, 0x4c95, \
    { 0x8e, 0x43, 0xb2, 0xe9, 0x8d, 0x6d, 0x15, 0x74 }}

class NS_NO_VTABLE nsIFolderListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IFOLDERLISTENER_IID)

  enum { added = 1U };

  /* void OnItemAdded (in nsIRDFResource parentItem, in nsISupports item); */
  NS_IMETHOD OnItemAdded(nsIRDFResource *parentItem, nsISupports *item) = 0;

  enum { removed = 2U };

  /* void OnItemRemoved (in nsIRDFResource parentItem, in nsISupports item); */
  NS_IMETHOD OnItemRemoved(nsIRDFResource *parentItem, nsISupports *item) = 0;

  enum { propertyChanged = 4U };

  /* void OnItemPropertyChanged (in nsIRDFResource item, in nsIAtom property, in string oldValue, in string newValue); */
  NS_IMETHOD OnItemPropertyChanged(nsIRDFResource *item, nsIAtom *property, const char *oldValue, const char *newValue) = 0;

  enum { intPropertyChanged = 8U };

  /* void OnItemIntPropertyChanged (in nsIRDFResource item, in nsIAtom property, in long oldValue, in long newValue); */
  NS_IMETHOD OnItemIntPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRInt32 oldValue, PRInt32 newValue) = 0;

  enum { boolPropertyChanged = 16U };

  /* void OnItemBoolPropertyChanged (in nsIRDFResource item, in nsIAtom property, in boolean oldValue, in boolean newValue); */
  NS_IMETHOD OnItemBoolPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRBool oldValue, PRBool newValue) = 0;

  enum { unicharPropertyChanged = 32U };

  /* void OnItemUnicharPropertyChanged (in nsIRDFResource item, in nsIAtom property, in wstring oldValue, in wstring newValue); */
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIRDFResource *item, nsIAtom *property, const PRUnichar *oldValue, const PRUnichar *newValue) = 0;

  enum { propertyFlagChanged = 64U };

  /* void OnItemPropertyFlagChanged (in nsIMsgDBHdr item, in nsIAtom property, in unsigned long oldFlag, in unsigned long newFlag); */
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *item, nsIAtom *property, PRUint32 oldFlag, PRUint32 newFlag) = 0;

  enum { event = 128U };

  /* void OnItemEvent (in nsIMsgFolder item, in nsIAtom event); */
  NS_IMETHOD OnItemEvent(nsIMsgFolder *item, nsIAtom *event) = 0;

  enum { all = 4294967295U };

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFOLDERLISTENER \
  NS_IMETHOD OnItemAdded(nsIRDFResource *parentItem, nsISupports *item); \
  NS_IMETHOD OnItemRemoved(nsIRDFResource *parentItem, nsISupports *item); \
  NS_IMETHOD OnItemPropertyChanged(nsIRDFResource *item, nsIAtom *property, const char *oldValue, const char *newValue); \
  NS_IMETHOD OnItemIntPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRInt32 oldValue, PRInt32 newValue); \
  NS_IMETHOD OnItemBoolPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRBool oldValue, PRBool newValue); \
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIRDFResource *item, nsIAtom *property, const PRUnichar *oldValue, const PRUnichar *newValue); \
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *item, nsIAtom *property, PRUint32 oldFlag, PRUint32 newFlag); \
  NS_IMETHOD OnItemEvent(nsIMsgFolder *item, nsIAtom *event); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFOLDERLISTENER(_to) \
  NS_IMETHOD OnItemAdded(nsIRDFResource *parentItem, nsISupports *item) { return _to OnItemAdded(parentItem, item); } \
  NS_IMETHOD OnItemRemoved(nsIRDFResource *parentItem, nsISupports *item) { return _to OnItemRemoved(parentItem, item); } \
  NS_IMETHOD OnItemPropertyChanged(nsIRDFResource *item, nsIAtom *property, const char *oldValue, const char *newValue) { return _to OnItemPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemIntPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRInt32 oldValue, PRInt32 newValue) { return _to OnItemIntPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemBoolPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRBool oldValue, PRBool newValue) { return _to OnItemBoolPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIRDFResource *item, nsIAtom *property, const PRUnichar *oldValue, const PRUnichar *newValue) { return _to OnItemUnicharPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *item, nsIAtom *property, PRUint32 oldFlag, PRUint32 newFlag) { return _to OnItemPropertyFlagChanged(item, property, oldFlag, newFlag); } \
  NS_IMETHOD OnItemEvent(nsIMsgFolder *item, nsIAtom *event) { return _to OnItemEvent(item, event); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFOLDERLISTENER(_to) \
  NS_IMETHOD OnItemAdded(nsIRDFResource *parentItem, nsISupports *item) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemAdded(parentItem, item); } \
  NS_IMETHOD OnItemRemoved(nsIRDFResource *parentItem, nsISupports *item) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemRemoved(parentItem, item); } \
  NS_IMETHOD OnItemPropertyChanged(nsIRDFResource *item, nsIAtom *property, const char *oldValue, const char *newValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemIntPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRInt32 oldValue, PRInt32 newValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemIntPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemBoolPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRBool oldValue, PRBool newValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemBoolPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIRDFResource *item, nsIAtom *property, const PRUnichar *oldValue, const PRUnichar *newValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemUnicharPropertyChanged(item, property, oldValue, newValue); } \
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *item, nsIAtom *property, PRUint32 oldFlag, PRUint32 newFlag) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemPropertyFlagChanged(item, property, oldFlag, newFlag); } \
  NS_IMETHOD OnItemEvent(nsIMsgFolder *item, nsIAtom *event) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemEvent(item, event); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFolderListener : public nsIFolderListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFOLDERLISTENER

  nsFolderListener();

private:
  ~nsFolderListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFolderListener, nsIFolderListener)

nsFolderListener::nsFolderListener()
{
  /* member initializers and constructor code */
}

nsFolderListener::~nsFolderListener()
{
  /* destructor code */
}

/* void OnItemAdded (in nsIRDFResource parentItem, in nsISupports item); */
NS_IMETHODIMP nsFolderListener::OnItemAdded(nsIRDFResource *parentItem, nsISupports *item)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemRemoved (in nsIRDFResource parentItem, in nsISupports item); */
NS_IMETHODIMP nsFolderListener::OnItemRemoved(nsIRDFResource *parentItem, nsISupports *item)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemPropertyChanged (in nsIRDFResource item, in nsIAtom property, in string oldValue, in string newValue); */
NS_IMETHODIMP nsFolderListener::OnItemPropertyChanged(nsIRDFResource *item, nsIAtom *property, const char *oldValue, const char *newValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemIntPropertyChanged (in nsIRDFResource item, in nsIAtom property, in long oldValue, in long newValue); */
NS_IMETHODIMP nsFolderListener::OnItemIntPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRInt32 oldValue, PRInt32 newValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemBoolPropertyChanged (in nsIRDFResource item, in nsIAtom property, in boolean oldValue, in boolean newValue); */
NS_IMETHODIMP nsFolderListener::OnItemBoolPropertyChanged(nsIRDFResource *item, nsIAtom *property, PRBool oldValue, PRBool newValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemUnicharPropertyChanged (in nsIRDFResource item, in nsIAtom property, in wstring oldValue, in wstring newValue); */
NS_IMETHODIMP nsFolderListener::OnItemUnicharPropertyChanged(nsIRDFResource *item, nsIAtom *property, const PRUnichar *oldValue, const PRUnichar *newValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemPropertyFlagChanged (in nsIMsgDBHdr item, in nsIAtom property, in unsigned long oldFlag, in unsigned long newFlag); */
NS_IMETHODIMP nsFolderListener::OnItemPropertyFlagChanged(nsIMsgDBHdr *item, nsIAtom *property, PRUint32 oldFlag, PRUint32 newFlag)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemEvent (in nsIMsgFolder item, in nsIAtom event); */
NS_IMETHODIMP nsFolderListener::OnItemEvent(nsIMsgFolder *item, nsIAtom *event)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFolderListener_h__ */
